% -------------------------------------------------------------------
%   load_sw01
%
%    load data from sensors on mooring SW01
%
% SW01			60	30 jul 19:35 	Structure mooring 
%						39 07.4425   73 17.2416
% 	SBE-39	311	14	-ends 8 Sept	SW01-SBE39-0311.dmp
%	Mini-T	2030	25			SW01-T2030.dat
%	Mini-T	2031	35 		        SW01-T2031.dat
%
% SBE ended on 9/8 07:13:28
%   start time =  29 Jul 2006  23:27:30
%   sample interval = 30 seconds
%
%
%   SW01 deployed     07/30 06:06
%   SW01 recovered    09/09 22:30  
% ------------------------------------------------------------------------

plotem = 1;

SW01.Zsens   = [ 14 25 35];
SW01.dep  = 60;
SW01.latd = 39; 
SW01.latm = 07.4425; 
SW01.lond = 73; 
SW01.lonm = 17.2416;
SW01.type = 'Smoor';
SW01.name = 'SW01';

% Use these to sync data... 
%% st_date = datenum(2006,7,30,19,40,00);
%% end_date = datenum(2006,9,9,22,30,00);
 

% SBE 0311   -   has temp and pressure
% load SW01-SBE39-0311.asc;
S0311 = read_sbe('SW01-SBE39-0311.asc','tp',SW01.name,SW01.Zsens(1));

% load SW01-T2030.asc;
T2030 = read_tpod('SW01-T2030.asc',SW01.name,SW01.Zsens(2));

% load SW01-T2031.asc;
T2031 = read_tpod('SW01-T2031.asc',SW01.name,SW01.Zsens(3));

 
% ----------------------------------------------------------------------

% Should we compensate the depths to the mean?
%% pmean = mean(S311.p);
%% pdiff = pmean - S311.dep;
%% S311.dep = pmean;

% ndx = find (S311.mday > st_date &  S311.mday < end_date );
% S311.mday = S311.mday(ndx);
% S311.t   = S311.t(ndx);
% S311.p  = S311.p(ndx);
 
% ndx = find (T2030.mday > st_date &  T2030.mday < end_date );
% T2030.mday = T2030.mday(ndx);
% T2030.t   = T2030.t(ndx);
 
% ndx = find (T2031.mday > st_date &  T2031.mday < end_date );
% T2031.mday = T2031.mday(ndx);
% T2031.t   = T2031.t(ndx);


% -------------------------------------------------------------------------------

save  SW01  SW01 T2031  T2030 S0311;

% -------------------------------------------------------------------------------
 

if (plotem) 

  figure(2); clf
  plot(T2030.mday,T2030.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2030  Temperature at %6.2fm Z',SW01.type,T2030.moor,T2030.dep);
  title(S,'interpreter','none');
 
   % -----------------------------------------------
   figure(1); clf
   subplot(211)
   plot(S0311.mday,S0311.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0311  Temperature at %6.2fm Z',SW01.type, S0311.moor,S0311.dep);
   title(S,'interpreter','none');

   subplot(212)
   plot(S0311.mday,S0311.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_0311  Pressure',SW01.type,S0311.moor);
   title(S,'interpreter','none');
   %%%  print -dps -Phpbw
 
  % -------------------------------------------------------

  figure(3); clf
  plot(T2031.mday,T2031.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2031  Temperature at %6.2fm Z',SW01.type,T2031.moor,T2031.dep);
  title(S,'interpreter','none');
end

