% -------------------------------------------------------------------
%   load_sw02
%
%    load data from sensors on mooring SW02
%
% SW02			60	30 jul 19:19	Structure mooring	
%						39 07.638    73 16.293
%	SBE39	313	14	-ends 7 Sept	SW02-SBE39-0313.cap
%	Mini-T	2032	25		 	SW02-T2032.dat
%	Mini-T	2033	35			SW02-T2033.dat
%
% ------------------------------------------------------------------------

SW02.Zsens   = [ 14 25 35];
SW02.dep  = 60;
SW02.latd = 39; 
SW02.latm = 07.638; 
SW02.lond = 73; 
SW02.lonm = 16.293;
SW02.type = 'Smoor';
SW02.name = 'SW02';

% Use these to sync data...
%% st_date = datenum(2006,7,30,19,20,00);
%% end_date = datenum(2006,9,9,22,20,00);
 

% load SW02-SBE39-0313.asc;
S0313 = read_sbe('SW02-SBE39-0313.asc','tp',SW02.name,SW02.Zsens(1));

% load SW02-T2032.asc;
T2032 = read_tpod('SW02-T2032.asc',SW02.name,SW02.Zsens(2));

% load SW02-T2033.asc;
T2033 = read_tpod('SW02-T2033.asc',SW02.name,SW02.Zsens(2));


plotem = 1;


% -------------------------------------------------------------------------------
 
% Should we compensate the depths to the mean?
%% pmean = mean(S313.p);
%% pdiff = pmean - S313.dep;
%% S313.dep = pmean;

% ndx = find (S313.mday > st_date &  S313.mday < end_date );
% S313.mday = S313.mday(ndx);
% S313.t   = S313.t(ndx);
% S313.p  = S313.p(ndx);
 
% ndx = find (T2032.mday > st_date &  T2032.mday < end_date );
% T2032.mday = T2032.mday(ndx);
% T2032.t   = T2032.t(ndx);
 
% ndx = find (T2033.mday > st_date &  T2033.mday < end_date );
% T2033.mday = T2033.mday(ndx);
% T2033.t   = T2033.t(ndx);

% -------------------------------------------------------------------------------

save  SW02  SW02 T2033  T2032 S0313;

% -------------------------------------------------------------------------------
 

if (plotem)
   figure(1); clf
   subplot(211)
   plot(S0313.mday,S0313.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0313  Temperature at %6.2fm Z',SW02.type, S0313.moor,S0313.dep);
   title(S,'interpreter','none');


   subplot(212)
   plot(S0313.mday,S0313.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_0313  Pressure',SW02.type,S0313.moor);
   title(S,'interpreter','none');


  figure(2); clf
  plot(T2032.mday,T2032.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2032  Temperature at %6.2fm Z',SW02.type,T2032.moor,T2032.dep);
  title(S,'interpreter','none');


  figure(3); clf
  plot(T2033.mday,T2033.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2033  Temperature at %6.2fm Z',SW02.type,T2033.moor,T2033.dep);
  title(S,'interpreter','none');
end

% --------------------------------------------------------------------------



