% -------------------------------------------------------------------
%   load_sw03
%
%    load data from sensors on mooring sw03
%
%  SW03			72.5	29 jul 18:54	Structure mooring	
%						39 04.278  73 10.200
% 	Mini-T	256       1   data noisy           	SW03-T0256.DAT 
% 	SBE39	317       14	-ends 8 Sept	 	SW03-SBE39-0317.cap
% 	Mini-T	2034	25                              SW03-T2034.dat
% 	Mini-T	2035	40                              SW03-T2035.dat
% 	Mini-T	2063	70                              SW03-T2063.dat
%  
%       SHOULD BE 2064  NOT 2063....   above
%
%            Will change later!
% 
%
% ------------------------------------------------------------------------

plotem = 1;

SW03.Zsens   = [ 1 14 25 40 70];
SW03.dep  = 72.5;
SW03.latd = 39; 
SW03.latm = 04.278; 
SW03.lond = 73; 
SW03.lonm = 10.2;
SW03.type = 'Smoor'; 
SW03.name = 'SW03';

% Use these to sync data...
%% st_date = datenum(2006,7,30,19,20,00);
%% end_date = datenum(2006,9,9,22,20,00);
 

% load SW03-SBE39-0317.asc;
S0317 = read_sbe('SW03-SBE39-0317.asc','tp',SW03.name,SW03.Zsens(2));

% load SW03-T2034.asc;
T2034 = read_tpod('SW03-T2034.asc',SW03.name,SW03.Zsens(3));

% load SW03-T2035.asc;
T2035 = read_tpod('SW03-T2035.asc',SW03.name,SW03.Zsens(4));

% load SW03-T2063.asc;
T2063 = read_tpod('SW03-T2063.asc',SW03.name,SW03.Zsens(5));

% noisy - dropouts to neg values.
% load SW03-T0256.asc;
T0256 = read_tpod('SW03-T0256.asc',SW03.name,SW03.Zsens(1));



% -----------------------------------------
 
% Should we compensate the depths to the mean?
pmean = mean(S0317.p);
pdiff = pmean - S0317.dep;
%% S0317.dep = pmean;

% ndx = find (S0317.mday > st_date &  S0317.mday < end_date );
% S0317.mday = S0317.mday(ndx);
% S0317.t   = S0317.t(ndx);
% S0317.p  = S0317.p(ndx);

% ndx = find (T2034.mday > st_date &  T2034.mday < end_date );
% T2034.mday = T2034.mday(ndx);
% T2034.t   = T2034.t(ndx);
 
 
% ndx = find (T2035.mday > st_date &  T2035.mday < end_date );
% T2035.mday = T2035.mday(ndx);
% T2035.t   = T2035.t(ndx);

% ndx = find (T2063.mday > st_date &  T2063.mday < end_date );
% T2063.mday = T2063.mday(ndx);
% T2063.t   = T2063.t(ndx);

% ndx = find (T0256.mday > st_date &  T0256.mday < end_date );
% T0256.mday = T0256.mday(ndx);
% T0256.t   = T0256.t(ndx);
 

% -------------------------------------------------------------------------------

save  SW03  SW03 T2034 T2035 T2063 T0256 S0317;

% -------------------------------------------------------------------------------
 
if (plotem)
   figure(1); clf
   subplot(211)
   plot(S0317.mday,S0317.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0317  Temperature at %6.2fm Z',SW03.type, S0317.moor,S0317.dep);
   title(S,'interpreter','none');

   subplot(212)
   plot(S0317.mday,S0317.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_0317  Pressure',SW03.type,S0317.moor);
   title(S,'interpreter','none');

  figure(2); clf
  plot(T2034.mday,T2034.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2034  Temperature at %6.2fm Z',SW03.type,T2034.moor,T2034.dep);
  title(S,'interpreter','none');
 
  figure(3); clf
  plot(T2035.mday,T2035.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2035  Temperature at %6.2fm Z',SW03.type,T2035.moor,T2035.dep);
  title(S,'interpreter','none');
 
  figure(4); clf
  plot(T2063.mday,T2063.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2063  Temperature at %6.2fm Z',SW03.type,T2063.moor,T2063.dep);
  title(S,'interpreter','none');
 
  figure(5); clf
  plot(T0256.mday,T0256.t); grid
  datetick
  set(gca,'ylim',[5 30]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T0256  Temperature at %6.2fm Z',SW03.type,T0256.moor,T0256.dep);
  title(S,'interpreter','none');
end
