% -------------------------------------------------------------------
%   load_sw04
%
%    load data from sensors on mooring sw04
%
%  SW04			83.5	31 jul 11:18	Structure mooring	
%					39 01.9776  73 05.0551
%	SBE39	323	14	SW04-SBE39-0323.cap
%	Mini-T	2038	25	SW04-T2038.dat
%	Mini-T	2039	40	1SW04-T2039.dat
%						
% 
%
% ------------------------------------------------------------------------

plotem = 1;


SW04.Zsens   = [ 14 25 40];
SW04.dep  = 83.5;
SW04.latd = 39; 
SW04.latm = 01.9776; 
SW04.lond = 73; 
SW04.lonm = 05.0551;
SW04.type = 'Smoor'; 
SW04.name = 'SW04';


% load SW04-SBE39-0323.asc;
S0323 = read_sbe('SW04-SBE39-0323.asc','tp',SW04.name,SW04.Zsens(1));

% load SW04-T2038.asc;
T2038 = read_tpod('SW04-T2038.asc',SW04.name,SW04.Zsens(2));

% load SW04-T2039.asc;
T2039 = read_tpod('SW04-T2039.asc',SW04.name,SW04.Zsens(3));



% -----------------------------------------
 

% Should we compensate the depths to the mean?
% pmean = mean(S0323.p);
% pdiff = pmean - S0323.dep;
%% S323.dep = pmean;


% Use these to sync data...
%% st_date = datenum(2006,7,30,19,20,00);
%% end_date = datenum(2006,9,9,22,20,00);


% ndx = find (S323.mday > st_date &  S323.mday < end_date );
% S323.mday = S323.mday(ndx);
% S323.t   = S323.t(ndx);
% S323.p  = S323.p(ndx);

% ndx = find (T2038.mday > st_date &  T2038.mday < end_date );
% T2038.mday = T2038.mday(ndx);
% T2038.t   = T2038.t(ndx);
 
% ndx = find (T2039.mday > st_date &  T2039.mday < end_date );
% T2039.mday = T2039.mday(ndx);
% T2039.t   = T2039.t(ndx);


% -------------------------------------------------------------------------------
 
save  SW04  SW04 T2038  T2039 S0323;

% -------------------------------------------------------------------------------
 

if (plotem)
   figure(1); clf
   subplot(211)
   plot(S0323.mday,S0323.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   title('Smoor sw04\_SBE39\_0323  Temperature at 14m Z');
   S = sprintf('%s %s_SBE39_0323  Temperature at %6.2fm Z',SW04.type, S0323.moor,S0323.dep);
   title(S,'interpreter','none');
 
   subplot(212)
   plot(S0323.mday,S0323.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_0323  Pressure',SW04.type,S0323.moor);
   title(S,'interpreter','none');

  
  figure(2); clf
  plot(T2038.mday,T2038.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2038  Temperature at %6.2fm Z',SW04.type,T2038.moor,T2038.dep);
  title(S,'interpreter','none');
 
  figure(3); clf
  plot(T2039.mday,T2039.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2039  Temperature at %6.2fm Z',SW04.type,T2039.moor,T2039.dep);
  title(S,'interpreter','none');
end

% -------------------------------------------------------------------------------
