% -------------------------------------------------------------------
%   load_sw05
%
%    load data from sensors on mooring sw05
%
% SW05			82.75	31 jul 11:40	Structure mooring	
%						39 02.213  73 04.8781
%	SBE39	324	14	SW05-SBE39-0324.dmp
%	Mini-T	2040	25	SW05-T2040.dat
%	Mini-T	2041	40	SW05-T2041.dat
%						
% 
%
% ------------------------------------------------------------------------

plotem = 1;

SW05.Zsens   = [ 14 25 40];
SW05.dep  = 82.75;
SW05.latd = 39; 
SW05.latm = 02.213; 
SW05.lond = 73; 
SW05.lonm = 04.8781;
SW05.type = 'Smoor'; 
SW05.name = 'SW05'; 
 
% Use these to sync data...
% st_date = datenum(2006,7,30,19,20,00);
% end_date = datenum(2006,9,9,22,20,00);
 

% load SW05-SBE39-0324.asc;
S0324 = read_sbe('SW05-SBE39-0324.asc','tp',SW05.name,SW05.Zsens(1));

% load SW05-T2040.asc;
T2040 = read_tpod('SW05-T2040.asc',SW05.name,SW05.Zsens(2));

% load SW05-T2041.asc;
T2041 = read_tpod('SW05-T2041.asc',SW05.name,SW05.Zsens(2)); 


% -----------------------------------------
 
% Should we compensate the depths to the mean?
%% pmean = mean(S324.p);
%% pdiff = pmean - S324.dep;
%% S324.dep = pmean;

% ndx = find (S324.mday > st_date &  S324.mday < end_date );
% S324.mday = S324.mday(ndx);
% S324.t   = S324.t(ndx);
% S324.p  = S324.p(ndx);
 
% ndx = find (T2040.mday > st_date &  T2040.mday < end_date );
% T2040.mday = T2040.mday(ndx);
% T2040.t   = T2040.t(ndx);

% ndx = find (T2041.mday > st_date &  T2041.mday < end_date );
% T2041.mday = T2041.mday(ndx);
% T2041.t   = T2041.t(ndx);


% -------------------------------------------------------------------------------
 
save  SW05  SW05 T2041  T2040 S324;

% -------------------------------------------------------------------------------
 
if (plotem)
   figure(1); clf
   subplot(211)
   plot(S324.mday,S324.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0324  Temperature at %6.2fm Z',SW05.type, S324.moor,S324.dep);
   title(S,'interpreter','none');

   subplot(212)
   plot(S324.mday,S324.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_0324  Pressure',SW05.type,S324.moor);
   title(S,'interpreter','none');
  
  figure(2); clf
  plot(T2040.mday,T2040.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2040  Temperature at %6.2fm Z',SW05.type,T2040.moor,T2040.dep);
  title(S,'interpreter','none');
 
  figure(3); clf
  plot(T2041.mday,T2041.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2041  Temperature at %6.2fm Z',SW05.type,T2041.moor,T2041.dep);
  title(S,'interpreter','none');
end

% --------------------------------------------------------------------------


