% -------------------------------------------------------------------
%   load_sw06
%
%    load data from sensors on mooring sw06
%
% SW06			83	31 jul 12:33	Structure mooring	
%					39 02.5721  73 04.6120
%	SBE39	326	14	SW06-SBE39-0326.dmp
%	Mini-T	2042	25	SW06-T2042.dat
%	Mini-T	2043	40	SW06-T2043.dat 
%						
% 
%
% ------------------------------------------------------------------------

plotem = 1;

SW06.Zsens   = [ 14 25 40];
SW06.dep  = 83.0;
SW06.latd = 39; 
SW06.latm = 02.5721; 
SW06.lond = 73; 
SW06.lonm = 04.612;
SW06.type = 'Smoor';
SW06.name = 'SW06';

 

% load SW06-SBE39-0326.asc;
S0326 = read_sbe('SW06-SBE39-0326.asc','tp',SW06.name,SW06.Zsens(1));

% load SW06-T2042.asc;
T2042 = read_tpod('SW06-T2042.asc',SW06.name,SW06.Zsens(2));

% load SW06-T2043.asc;
T2043 = read_tpod('SW06-T2043.asc',SW06.name,SW06.Zsens(2));
 

% -----------------------------------------
 
 
% Use these to sync data...
% st_date = datenum(2006,7,30,19,20,00);
% end_date = datenum(2006,9,9,22,20,00);

% Should we compensate the depths to the mean?
%% pmean = mean(S326.p);
%% pdiff = pmean - S326.dep;
%% S326.dep = pmean;
 
% ndx = find (S326.mday > st_date &  S326.mday < end_date );
% S326.mday = S326.mday(ndx);
% S326.t   = S326.t(ndx);
% S326.p  = S326.p(ndx);
 
% ndx = find (T2042.mday > st_date &  T2042.mday < end_date );
% T2042.mday = T2042.mday(ndx);
% T2042.t   = T2042.t(ndx);
 
% ndx = find (T2043.mday > st_date &  T2043.mday < end_date );
% T2043.mday = T2043.mday(ndx);
% T2043.t   = T2043.t(ndx);

% -------------------------------------------------------------------------------
 
save  SW06  SW06 T2043  T2042 S0326;

% -------------------------------------------------------------------------------
 

if (plotem)
   figure(1); clf
   subplot(211)
   plot(S0326.mday,S0326.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0326  Temperature at %6.2fm Z',SW06.type, S0326.moor,S0326.dep);
   title(S,'interpreter','none');

   subplot(212)
   plot(S0326.mday,S0326.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_0326  Pressure',SW06.type,S0326.moor);
   title(S,'interpreter','none');
  
  figure(2); clf
  plot(T2042.mday,T2042.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2042  Temperature at %6.2fm Z',SW06.type,T2042.moor,T2042.dep);
  title(S,'interpreter','none');
 
  figure(3); clf
  plot(T2043.mday,T2043.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2043  Temperature at %6.2fm Z',SW06.type,T2043.moor,T2043.dep);
  title(S,'interpreter','none');
end

% --------------------------------------------------------------------------
