% -------------------------------------------------------------------
%   load_sw07
%
%    load data from sensors on mooring sw07
%
% SW07			84.25	31 jul 14:36	Structure mooring	39 03.0240  73 04.272
%	SBE39	327	14	SW07-SBE39-0327.cap
%	Mini-T	2044	25	SW07-T2044.dat
%	Mini-T	2045	40	SW07-T2045.dat
%
% 
%
% ------------------------------------------------------------------------

plotem = 1;

SW07.Zsens   = [ 14 25 40];
SW07.dep  = 84.25;
SW07.latd = 39; 
SW07.latm = 03.0240; 
SW07.lond = 73; 
SW07.lonm = 04.272;
SW07.type = 'Smoor'; 
SW07.name = 'SW07';

% load SW07-SBE39-0327.asc;
S0327 = read_sbe('SW07-SBE39-0327.asc','tp',SW07.name,SW07.Zsens(1));

% load SW07-T2044.asc;
T2044 = read_tpod('SW07-T2044.asc',SW07.name,SW07.Zsens(2));

% load SW07-T2045.asc;
T2045 = read_tpod('SW07-T2045.asc',SW07.name,SW07.Zsens(2));
 

% -----------------------------------------
  
% Use these to sync data...
%% st_date = datenum(2006,7,30,19,20,00);
%% end_date = datenum(2006,9,9,22,20,00);
 

% Should we compensate the depths to the mean?
% pmean = mean(S0327.p);
% pdiff = pmean - S0327.dep;
%% S0327.dep = pmean;

% ndx = find (S327.mday > st_date &  S327.mday < end_date );
% S327.mday = S327.mday(ndx);
% S327.t   = S327.t(ndx);
% S327.p  = S327.p(ndx);

% ndx = find (T2044.mday > st_date &  T2044.mday < end_date );
% T2044.mday = T2044.mday(ndx);
% T2044.t   = T2044.t(ndx);

 
% ndx = find (T2045.mday > st_date &  T2045.mday < end_date );
% T2045.mday = T2045.mday(ndx);
% T2045.t   = T2045.t(ndx);


% -------------------------------------------------------------------------------
 
save  SW07  SW07 T2044  T2045 S0327;

% -------------------------------------------------------------------------------
 

if (plotem)
   figure(1); clf
   subplot(211)
   plot(S0327.mday,S0327.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');

   S = sprintf('%s %s_SBE39_0327  Temperature at %6.2fm Z',SW07.type, S0327.moor,S0327.dep);
   title(S,'interpreter','none');

   subplot(212)
   plot(S0327.mday,S0327.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_0327  Pressure',SW07.type,S0327.moor);
   title(S,'interpreter','none');
  
  figure(2); clf
  plot(T2044.mday,T2044.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)'); 
  S = sprintf('%s %s_T2044 Temperature at %6.2fm Z',SW07.type,T2044.moor,T2044.dep);
  title(S,'interpreter','none');
 
  figure(3); clf
  plot(T2045.mday,T2045.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2045  Temperature at %6.2fm Z',SW07.type,T2045.moor,T2045.dep);
  title(S,'interpreter','none');
end

% -------------------------------------------------------------------------------

