% -------------------------------------------------------------------
%   load_sw10
%
%    load data from sensors on mooring sw10
%
% SW10			87	31 jul 17:35	Structure mooring	
%						39 02.286  73 04.023
%	SBE37P	4694	14	-ends 5 Sept	SW10-SBE37-4694.cap
%	Mini-T	2053	25			SW10-T2053.dat
%	Mini-T	2061	40			SW10-T2061.dat
%									
%						
%  SBE37 has temp, pressure and conductivity.
%
% ------------------------------------------------------------------------

plotem = 1;

SW10.Zsens   = [ 14 25 40 ];
SW10.dep  = 87.0;
SW10.latd = 39; 
SW10.latm = 02.286; 
SW10.lond = 73; 
SW10.lonm = 04.023;
SW10.type = 'Smoor'; 
SW10.name = 'SW10';
 

% SBE 4694   -   has temp, conductivity, and pressure
% load SW10-SBE37-4694.asc;
S4694 = read_sbe('SW10-SBE37-4694.asc','tpc',SW10.name,SW10.Zsens(1));

% load SW10-T2053.asc;
T2053 = read_tpod('SW10-T2053.asc',SW10.name,SW10.Zsens(2));

% load SW10-T2061.asc;
T2061 = read_tpod('SW10-T2061.asc',SW10.name,SW10.Zsens(3));


% -----------------------------------------
 

% Should we compensate the depths to the mean?
pmean = mean(S4694.p);
pdiff = pmean - S4694.dep;
%% S4694.dep = pmean;


% Use these to sync data...
%% st_date = datenum(2006,7,30,19,20,00);
%% end_date = datenum(2006,9,9,22,20,00);

% ndx = find (S4694.mday > st_date &  S4694.mday < end_date );
% S4694.mday = S4694.mday(ndx);
% S4694.t   = S4694.t(ndx);
% S4694.p  = S4694.p(ndx);

% ndx = find (T2053.mday > st_date &  T2053.mday < end_date );
% T2053.mday = T2053.mday(ndx);
% T2053.t   = T2053.t(ndx);

% ndx = find (T2061.mday > st_date &  T2061.mday < end_date );
% T2061.mday = T2061.mday(ndx);
% T2061.t   = T2061.t(ndx);S4694.mday = datenum(S4694.yr,S4694.mon,S4694.day,S3


% -------------------------------------------------------------------------------
 
save  SW10  SW10 T2061  T2053 S4694;

% -------------------------------------------------------------------------------
 if (plotem)
   figure(1); clf
   subplot(311)
   plot(S4694.mday,S4694.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE37_4694  Temperature at %6.2fm Z',SW10.type, S4694.moor,S4694.dep);
   title(S,'interpreter','none');
 
   subplot(312)
   plot(S4694.mday,S4694.p); grid
   axis('ij');
   datetick
   set(gca,'ylim',[10 20]);
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE37_4694  Pressure',SW10.type,S4694.moor);
   title(S,'interpreter','none');
 
   subplot(313)
   plot(S4694.mday,S4694.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_4694  Conductivity',SW10.type,S4694.moor);
   title(S,'interpreter','none');
  
  figure(2); clf
  plot(T2053.mday,T2053.t); grid
  datetick; 
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2053  Temperature at %6.2fm Z',SW10.type,T2053.moor,T2053.dep);
  title(S,'interpreter','none');
 
  figure(3); clf
  plot(T2061.mday,T2061.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date (2006)');
  S = sprintf('%s %s_T2061  Temperature at %6.2fm Z',SW10.type,T2061.moor,T2061.dep);
  title(S,'interpreter','none');
end
% --------------------------------------------------------------------------
