% -------------------------------------------------------------------
%   load_sw11
%
%    load data from sensors on mooring sw11
%
% SW11			85	31 jul 18:00	Structure mooring	
%						39 02.757  73 03.671
%	SBE39	322	14	-ends 8 Sept	SW11-SBE39-0322.cap
%	Mini-T	2076	25			SW11-T2076.dat
%	Mini-T	2077	40			SW11-T2077.dat
%									
%						
% 
%
% ------------------------------------------------------------------------

plotem = 1;

SW11.Zsens   = [ 14 25 40 ];
SW11.dep  = 85.0;
SW11.latd = 39; 
SW11.latm = 02.757; 
SW11.lond = 73; 
SW11.lonm = 03.671;
SW11.type = 'Smoor'; 
SW11.name = 'SW11';
 

% load SW11-SBE39-0322.asc;
S0322 = read_sbe('SW11-SBE39-0322.asc','tp',SW11.name,SW11.Zsens(1));

% load SW11-T2076.asc;
T2076 = read_tpod('SW11-T2076.asc',SW11.name,SW11.Zsens(2));

% load SW11-T2077.asc;
T2077 = read_tpod('SW11-T2077.asc',SW11.name,SW11.Zsens(3));


% -----------------------------------------
 
% Should we compensate the depths to the mean?
% pmean = mean(S322.p);
% pdiff = pmean - S322.dep;
%% S322.dep = pmean;


% Use these to sync data...
%% st_date = datenum(2006,7,30,19,20,00);
%% end_date = datenum(2006,9,9,22,20,00);

% ndx = find (S322.mday > st_date &  S322.mday < end_date );
% S322.mday = S322.mday(ndx);
% S322.t   = S322.t(ndx);
% S322.p  = S322.p(ndx);

% ndx = find (T2076.mday > st_date &  T2076.mday < end_date );
% T2076.mday = T2076.mday(ndx);
% T2076.t   = T2076.t(ndx);

% ndx = find (T2077.mday > st_date &  T2077.mday < end_date );
% T2077.mday = T2077.mday(ndx);
% T2077.t   = T2077.t(ndx);S322.mday = datenum(S322.yr,S322.mon,S322.day,S3

% -------------------------------------------------------------------------------
 
save  SW11  SW11 T2077  T2076 S0322;

% -------------------------------------------------------------------------------
 
if (plotem)
   figure(1); clf
   subplot(211)
   plot(S0322.mday,S0322.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0322  Temperature at %6.2fm Z',SW11.type, S0322.moor,S0322.dep);
   title(S,'interpreter','none');

   subplot(212)
   plot(S0322.mday,S0322.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_0322  Pressure',SW11.type,S0322.moor);
   title(S,'interpreter','none');
   %%%  print -dps -Phpbw

 
  figure(2); clf
  plot(T2076.mday,T2076.t); grid
  datetick; 
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2076  Temperature at %6.2fm Z',SW11.type,T2076.moor,T2076.dep);
  title(S,'interpreter','none');
 
  figure(3); clf
  plot(T2077.mday,T2077.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date (2006)');
  S = sprintf('%s %s_T2077  Temperature at %6.2fm Z',SW11.type,T2077.moor,T2077.dep);
  title(S,'interpreter','none');
end

% --------------------------------------------------------------------------

