% -------------------------------------------------------------------
%   load_sw12
%
%    load data from sensors on mooring sw12
%
% SW12			87.25	31 jul 22:58	Structure mooring	
%				39 01.734  73 03.828
%	W-ADCP	6580	8		SW012000.000
%	SBE37P	4848	14 -ends 5 Sept	SW12-SBE37-4848.cap
%	Mini-T	2066	25		SW12-T2066.dat
%	Mini-T	2087	40		SW12-T2087.dat
%									
%						
% 
%
% ------------------------------------------------------------------------

plotem = 1;

SW12.Zsens   = [ 14 25 40 ];
SW12.dep  = 87.25;
SW12.latd = 39; 
SW12.latm = 01.734; 
SW12.lond = 73; 
SW12.lonm = 03.828;
SW12.type = 'Smoor'; 
SW12.name = 'SW12';
 

% SBE 4848   -   has temp,conductivity, and pressure
% load SW12-SBE37-4848.asc;
S4848 = read_sbe('SW12-SBE37-4848.asc','tcp',SW12.name,SW12.Zsens(1));

% load SW12-T2066.asc;
T2066 = read_tpod('SW12-T2066.asc',SW12.name,SW12.Zsens(2));

% load SW12-T2087.asc;
T2087 = read_tpod('SW12-T2087.asc',SW12.name,SW12.Zsens(3)); 


% -----------------------------------------
 
% Should we compensate the depths to the mean?
% pmean = mean(S4848.p);
% pdiff = pmean - S4848.dep;
%% S4848.dep = pmean;

% Use these to sync data...
%% st_date = datenum(2006,7,30,19,20,00);
%% end_date = datenum(2006,9,9,22,20,00);
 
% ndx = find (S4848.mday > st_date &  S4848.mday < end_date );
% S4848.mday = S4848.mday(ndx);
% S4848.t   = S4848.t(ndx);
% S4848.p  = S4848.p(ndx);

% ndx = find (T2066.mday > st_date &  T2066.mday < end_date );
% T2066.mday = T2066.mday(ndx);
% T2066.t   = T2066.t(ndx);
 
% ndx = find (T2087.mday > st_date &  T2087.mday < end_date );
% T2087.mday = T2087.mday(ndx);
% T2087.t   = T2087.t(ndx);S4848.mday = datenum(S4848.yr,S4848.mon,S4848.day,S3


% -------------------------------------------------------------------------------
 
save  SW12  SW12 T2087  T2066 S4848;

% -------------------------------------------------------------------------------
 
if (plotem)
   figure(1); clf
   subplot(311)
   plot(S4848.mday,S4848.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE37_4848  Temperature at %6.2fm Z',SW12.type, S4848.moor,S4848.dep);
   title(S,'interpreter','none');

   subplot(312)
   plot(S4848.mday,S4848.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE37_4848  Pressure',SW12.type,S4848.moor);
   title(S,'interpreter','none');
   %%%  print -dps -Phpbw

   subplot(313)
   plot(S4848.mday,S4848.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_4848  Conductivity',SW12.type,S4848.moor);
   title(S,'interpreter','none');
 
  figure(2); clf
  plot(T2066.mday,T2066.t); grid
  datetick; 
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2066  Temperature at %6.2fm Z',SW12.type,T2066.moor,T2066.dep);
  title(S,'interpreter','none');
 
  figure(3); clf
  plot(T2087.mday,T2087.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date (2006)');
  S = sprintf('%s %s_T2087  Temperature at %6.2fm Z',SW12.type,T2087.moor,T2087.dep);
  title(S,'interpreter','none');
end
% --------------------------------------------------------------------------

