% -------------------------------------------------------------------
%   load_sw15
%
%    load data from sensors on mooring SW15
%
% SW15			80.5	01 aug 15:03	Structure mooring	
%					39 01.596  73 03.528
%	SBE39	3077	14	SW15-SBE39-3077.cap
%	Mini-T	2068	25	SW15-T2068.dat
%	Mini-T	1991	40	SW15-T1991.dat
%									
%						
% Need read_sbe.m and read_tpod.m functions.
%
% ------------------------------------------------------------------------
plotem = 1;

SW15.Zsens   = [ 14 25 40 ];
SW15.dep  = 80.5;
SW15.latd = 39; 
SW15.latm = 01.596; 
SW15.lond = 73; 
SW15.lonm = 03.528;
SW15.type = 'Smoor'; 
SW15.name = 'SW15';
 

% load SW15-SBE39-3077.asc;
S3077 = read_sbe('SW15-SBE39-3077.asc','tp',SW15.name,SW15.Zsens(1));

% load SW15-T2068.asc;
T2068 = read_tpod('SW15-T2068.asc',SW15.name,SW15.Zsens(2));

% load SW15-T1991.asc;
T1991 = read_tpod('SW15-T1991.asc',SW15.name,SW15.Zsens(3));
 


% -----------------------------------------
 
% Should we compensate the depths to the mean?
% pmean = mean(S3077.p);
% pdiff = pmean - S3077.dep;
%%% S3077.dep = pmean;

% Use these to sync data...
%% st_date = datenum(2006,7,30,19,20,00);
%% end_date = datenum(2006,9,9,22,20,00);
 

% ndx = find (S3077.mday > st_date &  S3077.mday < end_date );
% S3077.mday = S3077.mday(ndx);
% S3077.t   = S3077.t(ndx);
% S3077.p  = S3077.p(ndx);
 
% ndx = find (T2068.mday > st_date &  T2068.mday < end_date );
% T2068.mday = T2068.mday(ndx);
% T2068.t   = T2068.t(ndx);

% ndx = find (T1991.mday > st_date &  T1991.mday < end_date );
% T1991.mday = T1991.mday(ndx);
% T1991.t   = T1991.t(ndx);S3077.mday = datenum(S3077.yr,S3077.mon,S3077.day,S3

% -------------------------------------------------------------------------------
 
save  SW15  SW15 T1991  T2068 S3077;

% -------------------------------------------------------------------------------
 
if (plotem)
   figure(1); clf
   subplot(211)
   plot(S3077.mday,S3077.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_3077  Temperature at %6.2fm Z',SW15.type, S3077.moor,S3077.dep);
   title(S,'interpreter','none');

   subplot(212)
   plot(S3077.mday,S3077.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_3077  Pressure',SW15.type,S3077.moor);
   title(S,'interpreter','none');
  
  figure(2); clf
  plot(T2068.mday,T2068.t); grid
  datetick; 
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2068  Temperature at %6.2fm Z',SW15.type,T2068.moor,T2068.dep);
  title(S,'interpreter','none');
 
  figure(3); clf
  plot(T1991.mday,T1991.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date (2006)');
  S = sprintf('%s %s_T1991  Temperature at %6.2fm Z',SW15.type,T1991.moor,T1991.dep);
  title(S,'interpreter','none');
end

% -------------------------------------------------------------------------------

