% -------------------------------------------------------------------
%   load_sw17
%
%    load data from sensors on mooring sw17
%
% SW17			85	01 aug 16:26	Structure mooring	
%					39 02.423  73 02.912
%	SBE39	1939	14	SW17-SBD39-1939.dmp
%	Mini-T	1994	25	SW17-T1994.dat
%	Mini-T	1996	40	SW17-T1996.dat 
%									
%						
% 
%
% ------------------------------------------------------------------------

plotem = 1;

SW17.Zsens   = [ 14 25 40 ];
SW17.dep  = 85;
SW17.latd = 39; 
SW17.latm = 02.423; 
SW17.lond = 73; 
SW17.lonm = 02.912;
SW17.type = 'Smoor'; 
SW17.name = 'SW17';
 

% load SW17-SBE39-1939.asc;
S1939 = read_sbe('SW17-SBE39-1939.asc','tp',SW17.name,SW17.Zsens(1));

% load SW17-T1994.asc;
T1994 = read_tpod('SW17-T1994.asc',SW17.name,SW17.Zsens(3));

% load SW17-T1996.asc;
T1996 = read_tpod('SW17-T1996.asc',SW17.name,SW17.Zsens(3));
 

% -----------------------------------------

% Should we compensate the depths to the mean?
pmean = mean(S1939.p);
pdiff = pmean - S1939.dep;
%% S1939.dep = pmean;

% Use these to sync data...
%% st_date = datenum(2006,7,30,19,20,00);
%% end_date = datenum(2006,9,9,22,20,00);
 
% ndx = find (S1939.mday > st_date &  S1939.mday < end_date );
% S1939.mday = S1939.mday(ndx);
% S1939.t   = S1939.t(ndx);
% S1939.p  = S1939.p(ndx);

% ndx = find (T1994.mday > st_date &  T1994.mday < end_date );
% T1994.mday = T1994.mday(ndx);
% T1994.t   = T1994.t(ndx);

% ndx = find (T1996.mday > st_date &  T1996.mday < end_date );
% T1996.mday = T1996.mday(ndx);
% T1996.t   = T1996.t(ndx);S1939.mday = datenum(S1939.yr,S1939.mon,S1939.day,S3

% -------------------------------------------------------------------------------
 
save  SW17  SW17 T1996  T1994 S1939;

% -------------------------------------------------------------------------------
 
if (plotem)
   figure(1); clf
   subplot(211)
   plot(S1939.mday,S1939.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_1939  Temperature at %6.2fm Z',SW17.type, S1939.moor,S1939.dep);
   title(S,'interpreter','none');

   subplot(212)
   plot(S1939.mday,S1939.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_1939  Pressure',SW17.type,S1939.moor);
   title(S,'interpreter','none');
 
  figure(2); clf
  plot(T1994.mday,T1994.t); grid
  datetick; 
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T1994  Temperature at %6.2fm Z',SW17.type,T1994.moor,T1994.dep);
  title(S,'interpreter','none');
 
 
  figure(3); clf
  plot(T1996.mday,T1996.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date (2006)');
  S = sprintf('%s %s_T1996  Temperature at %6.2fm Z',SW17.type,T1996.moor,T1996.dep);
  title(S,'interpreter','none');
end

% -------------------------------------------------------------------------------
