% -------------------------------------------------------------------
%   load_sw18
%
%    load data from sensors on mooring sw18
%
% SW18			82.25	01 aug 13:13	Structure mooring	
%				39 03.231  73 02.771
%	SBE39	3119	14	 SW18-SBE39-3119.cap
%	Mini-T	2002	25	 SW18-T2002.dat
%	Mini-T	2001	40	 SW18-T2001.dat
%									
%						
% 
%
% ------------------------------------------------------------------------

plotem = 1;

SW18.Zsens   = [ 14 25 40 ];
SW18.dep  = 82.25;
SW18.latd = 39; 
SW18.latm = 03.231; 
SW18.lond = 73; 
SW18.lonm = 02.771;
SW18.type = 'Smoor';
SW18.name = 'SW18'; 


% SBE 3119   -   has temp and pressure
% load SW18-SBE39-3119.asc;
S3119 = read_sbe('SW18-SBE39-3119.asc','tp',SW18.name,SW18.Zsens(1));

% load SW18-T2002.asc;
T2002 = read_tpod('SW18-T2002.asc',SW18.name,SW18.Zsens(2));

% load SW18-T2001.asc;
T2001 = read_tpod('SW18-T2001.asc',SW18.name,SW18.Zsens(3));
 
 
% -----------------------------------------
 
% Should we compensate the depths to the mean?
pmean = mean(S3119.p);
pdiff = pmean - S3119.dep;
%% S3119.dep = pmean;

% Use these to sync data...
%% st_date = datenum(2006,7,30,19,20,00);
%% end_date = datenum(2006,9,9,22,20,00);

% ndx = find (S3119.mday > st_date &  S3119.mday < end_date );
% S3119.mday = S3119.mday(ndx);
% S3119.t   = S3119.t(ndx);
% S3119.p  = S3119.p(ndx);
 
% ndx = find (T2002.mday > st_date &  T2002.mday < end_date );
% T2002.mday = T2002.mday(ndx);
% T2002.t   = T2002.t(ndx);


% ndx = find (T2001.mday > st_date &  T2001.mday < end_date );
% T2001.mday = T2001.mday(ndx);
% T2001.t   = T2001.t(ndx);S3119.mday = datenum(S3119.yr,S3119.mon,S3119.day,S3

% -------------------------------------------------------------------------------
 
save  SW18  SW18 T2001  T2002 S3119;

% -------------------------------------------------------------------------------
 
if (plotem)
   figure(1); clf
   subplot(211)   %%%  print -dps -Phpbw

end

if (plotem) 
   plot(S3119.mday,S3119.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_3119  Temperature at %6.2fm Z',SW18.type, S3119.moor,S3119.dep);
   title(S,'interpreter','none');

   subplot(212)
   plot(S3119.mday,S3119.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_3119  Pressure',SW18.type,S3119.moor);
   title(S,'interpreter','none');
 
  figure(2); clf
  plot(T2002.mday,T2002.t); grid
  datetick; 
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2002  Temperature at %6.2fm Z',SW18.type,T2002.moor,T2002.dep);
  title(S,'interpreter','none');
 
  figure(3); clf
  plot(T2001.mday,T2001.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date (2006)');
  S = sprintf('%s %s_T2001  Temperature at %6.2fm Z',SW18.type,T2001.moor,T2001.dep);
  title(S,'interpreter','none');
end
 
% --------------------------------------------------------------------------

