% -------------------------------------------------------------------
%   load_SW19
%
%    load data from sensors on mooring SW19
%
% SW19			79	29 jul 13:20	Structure mooring	
%					39 06.17  73 00.5275
%	SBE39	3120	14	 SW19-SBE39-3120.dmp
%	Mini-T	2003	25	 SW19-T2003.dat
%	Mini-T	2004	40	 SW19-T2004.dat 
%									
%						
% 
%
% ------------------------------------------------------------------------
plotem = 1;

SW19.Zsens   = [ 14 25 40 ];
SW19.dep  = 79;
SW19.latd = 39; 
SW19.latm = 06.17; 
SW19.lond = 73; 
SW19.lonm = 00.5275;
SW19.type = 'Smoor'; 
SW19.name = 'SW19';


% SBE 3120   -   has temp and pressure
% load SW19-SBE39-3120.asc;
S3120 = read_sbe('SW19-SBE39-3120.asc','tp',SW19.name,SW19.Zsens(1));

% load SW19-T2003.asc;
T2003 = read_tpod('SW19-T2003.asc',SW19.name,SW19.Zsens(2));

% load SW19-T2004.asc;
T2004 = read_tpod('SW19-T2004.asc',SW19.name,SW19.Zsens(3));
 

% -----------------------------------------
  
% Should we compensate the depths to the mean?
pmean = mean(S3120.p);
pdiff = pmean - S3120.dep;
%% S3120.dep = pmean;
 
% Use these to sync data...
%% st_date = datenum(2006,7,30,19,20,00);
%% end_date = datenum(2006,9,9,22,20,00);


% ndx = find (S3120.mday > st_date &  S3120.mday < end_date );
% S3120.mday = S3120.mday(ndx);
% S3120.t   = S3120.t(ndx);
% S3120.p  = S3120.p(ndx);
 
% ndx = find (T2003.mday > st_date &  T2003.mday < end_date );
% T2003.mday = T2003.mday(ndx);
% T2003.t   = T2003.t(ndx);
 

% ndx = find (T2004.mday > st_date &  T2004.mday < end_date );
% T2004.mday = T2004.mday(ndx);
% T2004.t   = T2004.t(ndx);S3120.mday = datenum(S3120.yr,S3120.mon,S3120.day,S3

% -------------------------------------------------------------------------------
 
save  SW19  SW19 T2004  T2003 S3120;

% -------------------------------------------------------------------------------
 
if (plotem)
   figure(1); clf
   subplot(211)
   plot(S3120.mday,S3120.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_3120  Temperature at %6.2fm Z',SW19.type, S3120.moor,S3120.dep);
   title(S,'interpreter','none');

   subplot(212)
   plot(S3120.mday,S3120.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_3120  Pressure',SW19.type,S3120.moor);
   title(S,'interpreter','none');
 
  figure(2); clf
  plot(T2003.mday,T2003.t); grid
  datetick; 
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2003  Temperature at %6.2fm Z',SW19.type,T2003.moor,T2003.dep);
  title(S,'interpreter','none');
 
  figure(3); clf
  plot(T2004.mday,T2004.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date (2006)');
  S = sprintf('%s %s_T2004  Temperature at %6.2fm Z',SW19.type,T2004.moor,T2004.dep);
  title(S,'interpreter','none');
end

% -------------------------------------------------------------------------------
