% -------------------------------------------------------------------
%   load_SW20
%
%    load data from sensors on mooring SW20 
%
% SW20                  80.5    29 jul 12:28    Structure mooring 
%                                       39 06.3674  72 59.5731 
%       SBE39   3121    14       SW20-SBE39-3121.cap
%       Mini-T  2005    25       SW20-T2005.dat
%       Mini-T  2006    40       SW20-T2006.dat 					
% 
%
% ------------------------------------------------------------------------

plotem = 1;

SW20.Zsens   = [ 14 25 40 ];
SW20.dep  = 80.5;
SW20.latd = 39; 
SW20.latm = 06.3674; 
SW20.lond = 72; 
SW20.lonm = 59.5731;
SW20.type = 'Smoor'; 
SW20.name = 'SW20';
 

% SBE 3121   -   has temp and pressure
% load SW20-SBE39-3121.asc;
S3121 = read_sbe('SW20-SBE39-3121.asc','tp',SW20.name,SW20.Zsens(1));

% load SW20-T2005.asc;
T2005 = read_tpod('SW20-T2005.asc',SW20.name,SW20.Zsens(2));

% load SW20-T2006.asc;
T2006 = read_tpod('SW20-T2006.asc',SW20.name,SW20.Zsens(3));
 


% -----------------------------------------

% Should we compensate the depths to the mean?
% pmean = mean(S3121.p);
% pdiff = pmean - S3121.dep;
%% S3121.dep = pmean;

% Use these to sync data...
%% st_date = datenum(2006,7,30,19,20,00);
%% end_date = datenum(2006,9,9,22,20,00);
 
% ndx = find (S3121.mday > st_date &  S3121.mday < end_date );
% S3121.mday = S3121.mday(ndx);
% S3121.t   = S3121.t(ndx);
% S3121.p  = S3121.p(ndx);
 
% ndx = find (T2005.mday > st_date &  T2005.mday < end_date );
% T2005.mday = T2005.mday(ndx);
% T2005.t   = T2005.t(ndx);


% ndx = find (T2006.mday > st_date &  T2006.mday < end_date );
% T2006.mday = T2006.mday(ndx);
% T2006.t   = T2006.t(ndx);S3121.mday = datenum(S3121.yr,S3121.mon,S3121.day,S3

% -------------------------------------------------------------------------------
 
save  SW20  SW20 T2006  T2005 S3121;

% -------------------------------------------------------------------------------
 
 
if (plotem)
   figure(1); clf
   subplot(211)
   plot(S3121.mday,S3121.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_3121  Temperature at %6.2fm Z',SW20.type, S3121.moor,S3121.dep);
   title(S,'interpreter','none');

   subplot(212)
   plot(S3121.mday,S3121.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_3121  Pressure',SW20.type,S3121.moor);
   title(S,'interpreter','none');
  
 
  figure(2); clf
  plot(T2005.mday,T2005.t); grid
  datetick; 
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2005  Temperature at %6.2fm Z',SW20.type,T2005.moor,T2005.dep);
  title(S,'interpreter','none');
 
  figure(3); clf
  plot(T2006.mday,T2006.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date (2006)');
  S = sprintf('%s %s_T2006  Temperature at %6.2fm Z',SW20.type,T2006.moor,T2006.dep);
  title(S,'interpreter','none');
end

% -------------------------------------------------------------------------------
