% -------------------------------------------------------------------
%   load_SW22
%
%    load data from sensors on mooring SW22 
%
% SW22			79.5	28 jul 18:53	Structure mooring	
%					39 13.387  72 54.358
%	SBE39	3123	14	 SW22-SBE39-3123.cap
%	Mini-T	2010	25	 SW22-T2010.dat
%	Mini-T	2011	40	 SW22-T2011.dat
%
%
% ------------------------------------------------------------------------

plotem = 1;

SW22.Zsens   = [ 14 25 40 ];
SW22.dep  = 79.5;
SW22.latd = 39; 
SW22.latm = 13.387; 
SW22.lond = 72; 
SW22.lonm = 54.358;
SW22.type = 'Smoor'; 
SW22.name = 'SW22';

% SBE 3123   -   has temp and pressure
% load SW22-SBE39-3123.asc;
S3123 = read_sbe('SW22-SBE39-3123.asc','tp',SW22.name,SW22.Zsens(1));

% load SW22-T2010.asc;
T2010 = read_tpod('SW22-T2010.asc',SW22.name,SW22.Zsens(2));

% load SW22-T2011.asc;
T2011 = read_tpod('SW22-T2011.asc',SW22.name,SW22.Zsens(3));


% -----------------------------------------

% Should we compensate the depths to the mean?
% pmean = mean(S3123.p);
% pdiff = pmean - S3123.dep;
%% S3123.dep = pmean;
 
% Use these to sync data...
%% st_date = datenum(2011,7,30,19,20,00);
%% end_date = datenum(2011,9,9,22,20,00);
 
% ndx = find (S3123.mday > st_date &  S3123.mday < end_date );
% S3123.mday = S3123.mday(ndx);
% S3123.t   = S3123.t(ndx);
% S3123.p  = S3123.p(ndx);

% ndx = find (T2010.mday > st_date &  T2010.mday < end_date );
% T2010.mday = T2010.mday(ndx);
% T2010.t   = T2010.t(ndx);

% ndx = find (T2011.mday > st_date &  T2011.mday < end_date );
% T2011.mday = T2011.mday(ndx);
% T2011.t   = T2011.t(ndx);S3123.mday = datenum(S3123.yr,S3123.mon,S3123.day,S3

% -------------------------------------------------------------------------------
 
save  SW22  SW22 T2011  T2010 S3123;

% -------------------------------------------------------------------------------
 
 
if (plotem)
   figure(1); clf
   subplot(211)
   plot(S3123.mday,S3123.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_3123  Temperature at %6.2fm Z',SW22.type, S3123.moor,S3123.dep);
   title(S,'interpreter','none');

   subplot(212)
   plot(S3123.mday,S3123.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_3123  Pressure',SW22.type,S3123.moor);
   title(S,'interpreter','none');
 
 
  figure(2); clf
  plot(T2010.mday,T2010.t); grid
  datetick; 
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2010  Temperature at %6.2fm Z',SW22.type,T2010.moor,T2010.dep);
  title(S,'interpreter','none');
 
  figure(3); clf
  plot(T2011.mday,T2011.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date (2011)');
  S = sprintf('%s %s_T2011  Temperature at %6.2fm Z',SW22.type,T2011.moor,T2011.dep);
  title(S,'interpreter','none');
end

% -------------------------------------------------------------------------------
