% -------------------------------------------------------------------
%   load_SW23
%
%    load data from sensors on mooring SW23 
%
% SW23			87.75	26 jul 16:16	Structure mooring	
%					38 58.513  72 57.368
%	SBE39	3124	14	 SW23-SBE39-3124.cap
%	Mini-T	2012	25	 SW23-T2012.dat
%	Mini-T	2013	40	 SW23-T2013.dat
%	Mini-T	2063	85.25	 SW23-T2063.dat
%				
% 
%
% ------------------------------------------------------------------------

plotem = 1;

SW23.Zsens   = [ 14 25 40 85.25];
SW23.dep  = 87.75;
SW23.latd = 38; 
SW23.latm = 58.513; 
SW23.lond = 72; 
SW23.lonm = 57.368;
SW23.type = 'Smoor'; 
SW23.name = 'SW23';

 
% SBE 3124   -   has temp and pressure
% load SW23-SBE39-3124.asc;
S3124 = read_sbe('SW23-SBE39-3124.asc','tp',SW23.name,SW23.Zsens(1));

% load SW23-T2012.asc;
T2012 = read_tpod('SW23-T2012.asc',SW23.name,SW23.Zsens(2));

% load SW23-T2013.asc;
T2013 = read_tpod('SW23-T2013.asc',SW23.name,SW23.Zsens(3));

% load SW23-T2063.asc; 
T2063 = read_tpod('SW23-T2063.asc',SW23.name,SW23.Zsens(4));


% -----------------------------------------
 
% Should we compensate the depths to the mean?
% pmean = mean(S3124.p);
% pdiff = pmean - S3124.dep;
%% S3124.dep = pmean;
 
% Use these to sync data...
%% st_date = datenum(2013,7,30,19,20,00);
%% end_date = datenum(2013,9,9,22,20,00);

% ndx = find (S3124.mday > st_date &  S3124.mday < end_date );
% S3124.mday = S3124.mday(ndx);
% S3124.t   = S3124.t(ndx);
% S3124.p  = S3124.p(ndx);

% ndx = find (T2012.mday > st_date &  T2012.mday < end_date );
% T2012.mday = T2012.mday(ndx);
% T2012.t   = T2012.t(ndx);

% ndx = find (T2013.mday > st_date &  T2013.mday < end_date );
% T2013.mday = T2013.mday(ndx);
% T2013.t   = T2013.t(ndx); 

% ndx = find (T2063.mday > st_date &  T2063.mday < end_date );
% T2063.mday = T2063.mday(ndx);
% T2063.t   = T2063.t(ndx); 

% -------------------------------------------------------------------------------
 
save  SW23  SW23 T2013 T2063  T2012 S3124;

% -------------------------------------------------------------------------------
 
if (plotem)
   figure(1); clf
   subplot(211)
   plot(S3124.mday,S3124.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_3124  Temperature at %6.2fm Z',SW23.type, S3124.moor,S3124.dep);
   title(S,'interpreter','none');

   subplot(212)
   plot(S3124.mday,S3124.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_3124  Pressure',SW23.type,S3124.moor);
   title(S,'interpreter','none');
 
  figure(2); clf
  plot(T2012.mday,T2012.t); grid
  datetick; 
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2012  Temperature at %6.2fm Z',SW23.type,T2012.moor,T2012.dep);
  title(S,'interpreter','none');
 
  figure(3); clf
  plot(T2013.mday,T2013.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date (2013)');
  S = sprintf('%s %s_T2013  Temperature at %6.2fm Z',SW23.type,T2013.moor,T2013.dep);
  title(S,'interpreter','none');
 
  figure(4); clf
  plot(T2063.mday,T2063.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date (2063)');
  S = sprintf('%s %s_T2063  Temperature at %6.2fm Z',SW23.type,T2063.moor,T2063.dep);
  title(S,'interpreter','none');
end
% -------------------------------------------------------------------------------

