% -------------------------------------------------------------------
%   load_SW24
%
%    load data from sensors on mooring SW24 
%
% SW24			106.5	26 jul 16:50	Structure mooring	
%					38 57.439  72 54.963
%	SBE39	3125	14	 SW24-SBE39-3125.cap
%	Mini-T	2014	25	 SW24-T2014.dat
%	Mini-T	2015	40	 SW24-T2015.dat
%	Mini-T	2016	65	 SW24-T2016.dat
%				
%     The SBE data has bad date/time data.  Will have to either download
%		again or hand edit
%
% ------------------------------------------------------------------------

plotem = 1;

SW24.Zsens   = [ 14 25 40 65];
SW24.dep  = 106.5;
SW24.latd = 38; 
SW24.latm = 57.439; 
SW24.lond = 72; 
SW24.lonm = 54.963;
SW24.type = 'Smoor'; 
SW24.name = 'SW24';
 

 
% SBE 3125   -   has temp and pressure
% load SW24-SBE39-3125.asc;
%%%% 3125 = read_sbe('SW24-SBE39-3125.asc','tp',SW24.name,SW24.Zsens(1));
S3125 = read_sbe('SW24-SBE39-3125_new.asc','tp',SW24.name,SW24.Zsens(1));

% load SW24-T2014.asc;
T2014 = read_tpod('SW24-T2014.asc',SW24.name,SW24.Zsens(2));

% load SW24-T2015.asc;
T2015 = read_tpod('SW24-T2015.asc',SW24.name,SW24.Zsens(3));

% load SW24-T2016.asc; 
T2016 = read_tpod('SW24-T2016.asc',SW24.name,SW24.Zsens(4));


% ----------------------------------------

% Should we compensate the depths to the mean?
% pmean = mean(S3125.p);
% pdiff = pmean - S3125.dep;
%% S3125.dep = pmean;

% Use these to sync data...
%% st_date = datenum(2014,7,30,19,20,00);
%% end_date = datenum(2014,9,9,22,20,00);

% ndx = find (S3125.mday > st_date &  S3125.mday < end_date );
% S3125.mday = S3125.mday(ndx);
% S3125.t   = S3125.t(ndx);
% S3125.p  = S3125.p(ndx);

% ndx = find (T2014.mday > st_date &  T2014.mday < end_date );
% T2014.mday = T2014.mday(ndx);
% T2014.t   = T2014.t(ndx);

% ndx = find (T2015.mday > st_date &  T2015.mday < end_date );
% T2015.mday = T2015.mday(ndx);
% T2015.t   = T2015.t(ndx);S3125. 

% ndx = find (T2016.mday > st_date &  T2016.mday < end_date );
% T2016.mday = T2016.mday(ndx);
% T2016.t   = T2016.t(ndx); 


% -------------------------------------------------------------------------------
 
save  SW24  SW24 T2014 T2016  T2015 S3125;

% -------------------------------------------------------------------------------
 
if (plotem)
   figure(1); clf
   subplot(211)
   plot(S3125.mday,S3125.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_3125  Temperature at %6.2fm Z',SW24.type, S3125.moor,S3125.dep);
   title(S,'interpreter','none');

   subplot(212)
   plot(S3125.mday,S3125.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_3125  Pressure',SW24.type,S3125.moor);
   title(S,'interpreter','none');
  
  figure(2); clf
  plot(T2014.mday,T2014.t); grid
  datetick; 
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2014  Temperature at %6.2fm Z',SW24.type,T2014.moor,T2014.dep);
  title(S,'interpreter','none');
 
  figure(3); clf
  plot(T2015.mday,T2015.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date (2014)');
  S = sprintf('%s %s_T2015  Temperature at %6.2fm Z',SW24.type,T2015.moor,T2015.dep);
  title(S,'interpreter','none');
 
  figure(4); clf
  plot(T2016.mday,T2016.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date (2016)');
  S = sprintf('%s %s_T2016  Temperature at %6.2fm Z',SW24.type,T2016.moor,T2016.dep);
  title(S,'interpreter','none');
end
% -------------------------------------------------------------------------------
