% -------------------------------------------------------------------
%   load_SW25
%
%    load data from sensors on mooring SW25 
%
% SW25			110	26 jul 14:21	Structure mooring	
%					38 57.1573  72 54.3898
%	SBE39	3126	14	 SW25-SBE39-3126.cap
%	Mini-T	2017	25	 SW25-T2017.dat
%	Mini-T	2018	40	 SW25-T2018.dat
%	Mini-T	2019	65	 SW25-T2019.dat
% 
%
%
%     the SBE data has bad date/time data.  WIll have to either download
%		again or hand edit
% ------------------------------------------------------------------------

plotem = 1;

SW25.Zsens   = [ 14 25 40 65];
SW25.dep  = 110;
SW25.latd = 38; 
SW25.latm = 57.1573; 
SW25.lond = 72; 
SW25.lonm = 54.3898;
SW25.type = 'Smoor'; 
SW25.name = 'SW25';
 

%   bad time/date data in file
% load SW25-SBE39-3126.asc;
bad_sbe = 0;
if (bad_sbe ~= 1)
    S3126 = read_sbe('SW25-SBE39-3126_new.asc','tp',SW25.name,SW25.Zsens(1));
end

% load SW25-T2017.asc;
T2017 = read_tpod('SW25-T2017.asc',SW25.name,SW25.Zsens(2));

% load SW25-T2018.asc;
T2018 = read_tpod('SW25-T2018.asc',SW25.name,SW25.Zsens(3));

% load SW25-T2019.asc; 
T2019 = read_tpod('SW25-T2019.asc',SW25.name,SW25.Zsens(4));


% -----------------------------------------
 
% Should we compensate the depths to the mean?
% pmean = mean(S3126.p);
% pdiff = pmean - S3126.dep;
%% S3126.dep = pmean;

% Use these to sync data...
%% st_date = datenum(2018,7,30,19,20,00);
%% end_date = datenum(2018,9,9,22,20,00);
 
% ndx = find (S3126.mday > st_date &  S3126.mday < end_date );
% S3126.mday = S3126.mda% SBE 3127   -   has temp and pressurey(ndx);
% S3126.t   = S3126.t(ndx);
% S3126.p  = S3126.p(ndx);

% ndx = find (T2017.mday > st_date &  T2017.mday < end_date );
% T2017.mday = T2017.mday(ndx);
% T2017.t   = T2017.t(ndx);

% ndx = find (T2018.mday > st_date &  T2018.mday < end_date );
% T2018.mday = T2018.mday(ndx);
% T2018.t   = T2018.t(ndx);

% ndx = find (T2019.mday > st_date &  T2019.mday < end_date );
% T2019.mday = T2019.mday(ndx);
% T2019.t   = T2019.t(ndx); 

% -------------------------------------------------------------------------------
 
%%%% save  SW25  SW25 T2018 T2019  T2017 S3126;

save  SW25  SW25 T2018 T2019  T2017;

% -------------------------------------------------------------------------------
 

if (plotem)
  if (bad_sbe ~= 1)
   figure(1); clf
   subplot(211)
   plot(S3126.mday,S3126.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_3126  Temperature at %6.2fm Z',SW25.type, S3126.moor,S3126.dep);
   title(S,'interpreter','none');

   subplot(212)
   plot(S3126.mday,S3126.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_3126  Pressure',SW25.type,S3126.moor);
   title(S,'interpreter','none');
   
  end   %bad sbe

  figure(2); clf
  plot(T2017.mday,T2017.t); grid
  datetick; 
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2017  Temperature at %6.2fm Z',SW25.type,T2017.moor,T2017.dep);
  title(S,'interpreter','none');
 
  figure(3); clf
  plot(T2018.mday,T2018.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date (2018)');
  S = sprintf('%s %s_T2018  Temperature at %6.2fm Z',SW25.type,T2018.moor,T2018.dep);
  title(S,'interpreter','none');
 
  figure(4); clf
  plot(T2019.mday,T2019.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date (2019)');
  S = sprintf('%s %s_T2019  Temperature at %6.2fm Z',SW25.type,T2019.moor,T2019.dep);
  title(S,'interpreter','none');
end
% -----------------------------------------------------------------------------
 
