% -------------------------------------------------------------------
%   load_SW26
%
%    load data from sensors on mooring SW26 
%
% SW26			113.75	26 jul 22:41	Structure mooring	
%				38 56.6108  72 53.1865
%	SBE39	3127	14	 SW26-SBE39-3127.cap
%	Mini-T	2020	25	 SW26-T2020.dat
%	Mini-T	2021	40	 SW26-T2021.dat
%	Mini-T	2022	65	 SW26-T2022.dat
%				
% 
%
% ------------------------------------------------------------------------
plotem = 1;

SW26.Zsens   = [ 14 25 40 65];
SW26.dep  = 113.75;
SW26.latd = 38; 
SW26.latm = 56.6108; 
SW26.lond = 72; 
SW26.lonm = 53.1865;
SW26.type = 'Smoor'; 
SW26.name = 'SW26';


% SBE 3127   -   has temp and pressure 
%  SBE 3127 had some bad date/times
% load SW26-SBE39-3127.asc;
S3127 = read_sbe('SW26-SBE39-3127_new.asc','tp',SW26.name,SW26.Zsens(1));

% load SW26-T2020.asc;
T2020 = read_tpod('SW26-T2020.asc',SW26.name,SW26.Zsens(2));

% load SW26-T2021.asc;
T2021 = read_tpod('SW26-T2021.asc',SW26.name,SW26.Zsens(3));

% load SW26-T2022.asc; 
T2022 = read_tpod('SW26-T2022.asc',SW26.name,SW26.Zsens(4));


% -----------------------------------------
 
% Should we compensate the depths to the mean?
% pmean = mean(S3127.p);
% pdiff = pmean - S3127.dep;
%% S3127.dep = pmean;

% Use these to sync data...
%% st_date = datenum(2021,7,30,19,20,00);
%% end_date = datenum(2021,9,9,22,20,00);

% ndx = find (S3127.mday > st_date &  S3127.mday < end_date );
% S3127.mday = S3127.mday(ndx);
% S3127.t   = S3127.t(ndx);
% S3127.p  = S3127.p(ndx);

% ndx = find (T2020.mday > st_date &  T2020.mday < end_date );
% T2020.mday = T2020.mday(ndx);
% T2020.t   = T2020.t(ndx);

% ndx = find (T2021.mday > st_date &  T2021.mday < end_date );
% T2021.mday = T2021.mday(ndx);
% T2021.t   = T2021.t(ndx); 

% ndx = find (T2022.mday > st_date &  T2022.mday < end_date );
% T2022.mday = T2022.mday(ndx);
% T2022.t   = T2022.t(ndx); 


% -------------------------------------------------------------------------------
 
save  SW26  SW26 T2021 T2022  T2020 S3127;

% -------------------------------------------------------------------------------
 
if (plotem)
   figure(1); clf
   subplot(211)
   plot(S3127.mday,S3127.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_3127  Temperature at %6.2fm Z',SW26.type, S3127.moor,S3127.dep);
   title(S,'interpreter','none');

   subplot(212)
   plot(S3127.mday,S3127.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_3127  Pressure',SW26.type,S3127.moor);
   title(S,'interpreter','none');
   
  figure(2); clf
  plot(T2020.mday,T2020.t); grid
  datetick; 
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2020  Temperature at %6.2fm Z',SW26.type,T2020.moor,T2020.dep);
  title(S,'interpreter','none');
 
  figure(3); clf
  plot(T2021.mday,T2021.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date (2021)');
  S = sprintf('%s %s_T2021  Temperature at %6.2fm Z',SW26.type,T2021.moor,T2021.dep);
  title(S,'interpreter','none');
 
  figure(4); clf
  plot(T2022.mday,T2022.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date (2022)');
  S = sprintf('%s %s_T2022  Temperature at %6.2fm Z',SW26.type,T2022.moor,T2022.dep);
  title(S,'interpreter','none');
end
% -------------------------------------------------------------------------------
