% -------------------------------------------------------------------
%   load_SW27
%
%    load data from sensors on mooring SW27 
%
% SW27			122.5	27 jul 15:04	Structure mooring	
% 				38 56.8566  72 52.2051
%	SBE39	3128	14	 SW27-SBE39-3128.cap
%	Mini-T	2024	25	 SW27-T2024.dat
%	Mini-T	2025	40	 SW27-T2025.dat
%	Mini-T	2026	65	 SW27-T2026.dat
%				
% 
%
% ------------------------------------------------------------------------

plotem = 1;

SW27.Zsens   = [ 14 25 40 65];
SW27.dep  = 122.5;
SW27.latd = 38; 
SW27.latm = 56.8566; 
SW27.lond = 72; 
SW27.lonm = 52.2051;
SW27.type = 'Smoor'; 
SW27.name = 'SW27';

% SBE 3128   -   has temp and pressure
% load SW27-SBE39-3128.asc;
S3128 = read_sbe('SW27-SBE39-3128.asc','tp',SW27.name,SW27.Zsens(1));

% load SW27-T2024.asc;
T2024 = read_tpod('SW27-T2024.asc',SW27.name,SW27.Zsens(2));

% load SW27-T2025.asc;
T2025 = read_tpod('SW27-T2025.asc',SW27.name,SW27.Zsens(3));

% load SW27-T2026.asc; 
T2026 = read_tpod('SW27-T2026.asc',SW27.name,SW27.Zsens(4));


% -----------------------------------------
 
% Should we compensate the depths to the mean?
% pmean = mean(S3128.p);
% pdiff = pmean - S3128.dep;
%% S3128.dep = pmean;
 
% Use these to sync data...
%% st_date = datenum(2025,7,30,19,20,00);
%% end_date = datenum(2025,9,9,22,20,00);

% ndx = find (S3128.mday > st_date &  S3128.mday < end_date );
% S3128.mday = S3128.mday(ndx);
% S3128.t   = S3128.t(ndx);
% S3128.p  = S3128.p(ndx);

% ndx = find (T2024.mday > st_date &  T2024.mday < end_date );
% T2024.mday = T2024.mday(ndx);
% T2024.t   = T2024.t(ndx);

% ndx = find (T2025.mday > st_date &  T2025.mday < end_date );
% T2025.mday = T2025.mday(ndx);
% T2025.t   = T2025.t(ndx);  

% ndx = find (T2026.mday > st_date &  T2026.mday < end_date );
% T2026.mday = T2026.mday(ndx);
% T2026.t   = T2026.t(ndx); 


% -------------------------------------------------------------------------------
 
save  SW27  SW27 T2025 T2026  T2024 S3128;

% -------------------------------------------------------------------------------
 
if (plotem)
   figure(1); clf
   subplot(211)
   plot(S3128.mday,S3128.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_3128  Temperature at %6.2fm Z',SW27.type, S3128.moor,S3128.dep);
   title(S,'interpreter','none');

   subplot(212)
   plot(S3128.mday,S3128.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_3128  Pressure',SW27.type,S3128.moor);
   title(S,'interpreter','none');
  
  figure(2); clf
  plot(T2024.mday,T2024.t); grid
  datetick; 
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2024  Temperature at %6.2fm Z',SW27.type,T2024.moor,T2024.dep);
  title(S,'interpreter','none');
 
  figure(3); clf
  plot(T2025.mday,T2025.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date (2025)');
  S = sprintf('%s %s_T2025  Temperature at %6.2fm Z',SW27.type,T2025.moor,T2025.dep);
  title(S,'interpreter','none');
 
  figure(4); clf
  plot(T2026.mday,T2026.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date (2026)');
  S = sprintf('%s %s_T2026  Temperature at %6.2fm Z',SW27.type,T2026.moor,T2026.dep);
  title(S,'interpreter','none');
end
% -------------------------------------------------------------------------------
