% -------------------------------------------------------------------
%   load_SW28
%
%    load data from sensors on mooring SW28 
%
% SW28			122.5	27 jul 15:51	Structure mooring	
%				38 57.3049  72 51.8666
%	SBE39	3129	14	 SW28-SBE39-3129.cap
%	Mini-T	2027	25	 SW28-T2027.dat
%	Mini-T	2028	40	 SW28-T2028.dat
%	Mini-T	2029	65	 SW28-T2029.dat
%				
% 
%
% ------------------------------------------------------------------------

plotem = 1;

SW28.Zsens   = [ 14 25 40 65];
SW28.dep  = 122.5;
SW28.latd = 38; 
SW28.latm = 57.3049; 
SW28.lond = 72; 
SW28.lonm = 51.8666;
SW28.type = 'Smoor'; 
SW28.name = 'SW28';

% SBE 3129   -   has temp and pressure
% load SW28-SBE39-3129.asc;
S3129 = read_sbe('SW28-SBE39-3129.asc','tp',SW28.name,SW28.Zsens(1));

% load SW28-T2027.asc;
T2027 = read_tpod('SW28-T2027.asc',SW28.name,SW28.Zsens(2));

% load SW28-T2028.asc;
T2028 = read_tpod('SW28-T2028.asc',SW28.name,SW28.Zsens(3));

% load SW28-T2029.asc; 
T2029 = read_tpod('SW28-T2029.asc',SW28.name,SW28.Zsens(4));

% -----------------------------------------
 
% Should we compensate the depths to the mean?
% pmean = mean(S3129.p);
% pdiff = pmean - S3129.dep;
%% S3129.dep = pmean;
 
% Use these to sync data...
%% st_date = datenum(2028,7,30,19,20,00);
%% end_date = datenum(2028,9,9,22,20,00);

% ndx = find (S3129.mday > st_date &  S3129.mday < end_date );
% S3129.mday = S3129.mday(ndx);
% S3129.t   = S3129.t(ndx);
% S3129.p  = S3129.p(ndx);

% ndx = find (T2027.mday > st_date &  T2027.mday < end_date );
% T2027.mday = T2027.mday(ndx);
% T2027.t   = T2027.t(ndx);

% ndx = find (T2028.mday > st_date &  T2028.mday < end_date );
% T2028.mday = T2028.mday(ndx);
% T2028.t   = T2028.t(ndx); 

% ndx = find (T2029.mday > st_date &  T2029.mday < end_date );
% T2029.mday = T2029.mday(ndx);
% T2029.t   = T2029.t(ndx);     

% -------------------------------------------------------------------------------
 
save  SW28  SW28 T2028 T2029  T2027 S3129;

% -------------------------------------------------------------------------------
 

if (plotem)
   figure(1); clf
   subplot(211)
   plot(S3129.mday,S3129.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_3129  Temperature at %6.2fm Z',SW28.type, S3129.moor,S3129.dep);
   title(S,'interpreter','none');

   subplot(212)
   plot(S3129.mday,S3129.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_3129  Pressure',SW28.type,S3129.moor);
   title(S,'interpreter','none');
 
  figure(2); clf
  plot(T2027.mday,T2027.t); grid
  datetick; 
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2027  Temperature at %6.2fm Z',SW28.type,T2027.moor,T2027.dep);
  title(S,'interpreter','none');
 
  figure(3); clf
  plot(T2028.mday,T2028.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date');
  S = sprintf('%s %s_T2028  Temperature at %6.2fm Z',SW28.type,T2028.moor,T2028.dep);
  title(S,'interpreter','none');
 
  figure(4); clf
  plot(T2029.mday,T2029.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date');
  S = sprintf('%s %s_T2029  Temperature at %6.2fm Z',SW28.type,T2029.moor,T2029.dep);
  title(S,'interpreter','none');
end
% -------------------------------------------------------------------------------
