% -------------------------------------------------------------------
%   load_SW29
%
%    load data from sensors on mooring SW29 
%        ignoring the adcp for now
%        SBE16 (SW29-SBE16-2098) was not converted to ascii, in hex.
%
% SW29			62.5	30 jul 18:39	Env. Mooring	
%					39 07.1749  73 16.6399
%	Mini-T	275	1	  	SW29-T0275.dat
%	SBE37	406	12 -ends 31 Aug	SW29-SBE37-0406.cap
%	SBE39	3	21		SW29-SBE39-0003.dmp
%	SBE37	1133	31 -ends 7 Sept	SW29-SBE37-1133.cap
%	SBE39	4	42		SW29-SBE39-0004.cap
%	ADCP	125	55		SW029000.000
%	SBE16	2098	55		SW29-SBE16-2098.hex          HEX ONLY!!!
%	SBE26	306	55		   SW29WAVE.TID & SW29WAVE.WB 
%	Mini-T	263	60		SW29-T0263.dat
%				
% 
%   SBE39's     have temp only
%   SBE37#0406  has temp, conductivity, and pressure 
%   SBE37#1133  has temp and conductivity
%
% ------------------------------------------------------------------------
plotem = 1;

SW29.Zsens   = [1 12 21 31 42 55 55 55 60  ];
SW29.dep  = 62.5;
SW29.latd = 39; 
SW29.latm = 07.1749; 
SW29.lond = 73; 
SW29.lonm = 16.6399;
SW29.type = 'EnvMoor'; 
SW29.name = 'SW29';


% load SW29-T0275.asc;
T0275 = read_tpod('SW29-T0275.asc',SW29.name,SW29.Zsens(1));

% SBE37  0406    -   has temp, conductivity and pressure
% load SW29-SBE37-0406.asc;
S0406 = read_sbe('SW29-SBE37-0406.asc','tcp',SW29.name,SW29.Zsens(2));

% SBE 0003   -   has temp ONLY
% load SW29-SBE39-0003.asc;
S0003 = read_sbe('SW29-SBE39-0003_new.asc','t',SW29.name,SW29.Zsens(3));

% SBE37 1133   -   has temp and conductivity
% load SW29-SBE37-1133.asc;
S1133 = read_sbe('SW29-SBE37-1133.asc','tc',SW29.name,SW29.Zsens(4));

% load SW29-SBE39-0004.asc;  
% SBE 0004   -   has temp ONLY
S0004 = read_sbe('SW29-SBE39-0004.asc','t',SW29.name,SW29.Zsens(5));

%%% load SW29-SBE16-2098.asc;               %% Not converted to ascii, do not use...


% load SW29WAVE_tid.asc;  
S0306 = read_tidfile('SW29WAVE_tid.asc',SW29.name,SW29.Zsens(8)); 

load SW29-T0263.asc;
T0263 = read_tpod('SW29-T0263.asc',SW29.name,SW29.Zsens(9)); 

% -----------------------------------------
 
% Should we compensate the depths to the mean?
% pmean = mean(S0003.p);
% pdiff = pmean - S0003.dep;
%% S0003.dep = pmean;

% Use these to sync data...
%% st_date = datenum(0263,7,30,19,20,00);
%% end_date = datenum(0263,9,9,22,20,00);

% ndx = find (S0003.mday > st_date &  S0003.mday < end_date );
% S0003.mday = S0003.mday(ndx);
% S0003.t   = S0003.t(ndx);
% S0003.p  = S0003.p(ndx);

% ndx = find (S0004.mday > st_date &  S0004.mday < end_date );
% S0004.mday = S0004.mday(ndx);
% S0004.t   = S0004.t(ndx);
% S0004.p  = S0004.p(ndx);
 
% ndx = find (S1133.mday > st_date &  S1133.mday < end_date );
% S1133.mday = S1133.mday(ndx);
% S1133.t   = S1133.t(ndx);
% S1133.p  = S1133.p(ndx);

% ndx = find (S0406.mday > st_date &  S0406.mday < end_date );
% S0406.mday = S0406.mday(ndx);
% S0406.t   = S0406.t(ndx);
% S0406.p  = S0406.p(ndx);

% ndx = find (T0263.mday > st_date &  T0263.mday < end_date );
% T0263.mday = T0263.mday(ndx);
% T0263.t   = T0263.t(ndx);   
 

% -------------------------------------------------------------------------------
 
save  SW29  SW29 T0263  T0275 S0003 S0406 S0004 S1133 S0306 ;

% -------------------------------------------------------------------------------
 

if (plotem)
   figure(1); clf
   plot(S0003.mday,S0003.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0003  Temperature at %6.2fm Z',SW29.type, S0003.moor,S0003.dep);
   title(S,'interpreter','none');
  
   figure(2); clf
   plot(S0004.mday,S0004.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0004  Temperature at %6.2fm Z',SW29.type, S0004.moor,S0004.dep);
   title(S,'interpreter','none');
 
   figure(3); clf
   subplot(211)
   plot(S1133.mday,S1133.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_1133  Temperature at %6.2fm Z',SW29.type, S1133.moor,S1133.dep);
   title(S,'interpreter','none');

   
   subplot(212)
   plot(S1133.mday,S1133.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_1133  Conductivity',SW29.type,S1133.moor);
   title(S,'interpreter','none');
  
   figure(4); clf
   subplot(311)
   plot(S0406.mday,S0406.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0406  Temperature at %6.2fm Z',SW29.type, S0406.moor,S0406.dep);
   title(S,'interpreter','none');

   subplot(312)
   plot(S0406.mday,S0406.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_0406  Pressure',SW29.type,S0406.moor);
   title(S,'interpreter','none');

   subplot(313)
   plot(S0406.mday,S0406.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_0406  Conductivity',SW29.type,S0406.moor);
   title(S,'interpreter','none');
   %%%  print -dps -Phpbw

 
  figure(5); clf
  plot(T0275.mday,T0275.t); grid
  datetick; 
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T0275  Temperature at %6.2fm Z',SW29.type,T0275.moor,T0275.dep);
  title(S,'interpreter','none');
 
  figure(6); clf
  plot(T0263.mday,T0263.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date');
  S = sprintf('%s %s_T0263  Temperature at %6.2fm Z',SW29.type,T0263.moor,T0263.dep);
  title(S,'interpreter','none');
 
  figure(7); clf
  subplot(211)
  plot(S0306.mday,S0306.t); grid
  datetick
  % set(gca,'ylim',[5 27]);
  % ylabel('temp (C)');
  xlabel('Date');
  S = sprintf('%s %s_S0306  ????',SW29.type,S0306.moor);
  title(S,'interpreter','none');


  subplot(212)
  plot(S0306.mday,S0306.p); grid
  datetick
  %%% set(gca,'ylim',[5 27]);
  %%% ylabel('Pressure (dbar)');
  xlabel('Date');
  S = sprintf('%s %s_S0306  ?????? ',SW29.type,S0306.moor);
  title(S,'interpreter','none');


end

% -----------------------------------------
