% -------------------------------------------------------------------
%   load_SW30
%
%    load data from sensors on mooring SW30 
%        ignoring the adcp for now
%
% SW30			86	31 jul 21:25	Env. Mooring	
%					39 01.501  73 04.007
%	Mini-T	282	1		lost	
%	SBE37	4850	14  -ends 6 Sept	SW30-SBE37-4850.cap
%	SBE37	4841	17  -ends 7 Sept	SW30-SBE37-4841.cap
%	SBE37	4842	21  -ends 6 Sept	SW30-SBE37-4842.cap
%	SBE37	4843	26  -ends 6 Sept	SW30-SBE37-4843.cap
%	SBE37	4844	33  -ends 6 Sept	SW30-SBE37-4844.cap
%	SBE37	4845	40  -ends 6 Sept	SW30-SBE37-4845.cap
%	SBE37	4846	48  -ends 7 Sept	SW30-SBE37-4846.cap
%	SBE37	4847	57  -ends 6 Sept	SW30-SBE37-4847.cap
%	SBE37	4849	66  -ends 6 Sept	SW30-SBE37-4849.cap
%	SBE37	4851	75  -ends 5 Sept	SW30-SBE37-4851.cap
%	ADCP	6958	75 			SW030001.000 & .001
%	Mini-T	289	83.5 			SW30-T0282.dat
%				
% 
%   ALL SBE37's here have temp, conductivity, and pressure 
% 
%   See plotadcp_sw30.m  for plotting adcp data
%
% ------------------------------------------------------------------------

plotem = 1;

SW30.Zsens   = [1 14 17 21 26 33 40 48 57 66 75 75 83.3  ];
SW30.dep  = 86;
SW30.latd = 39; 
SW30.latm = 01.501; 
SW30.lond = 73; 
SW30.lonm = 04.007;
SW30.type = 'EnvMoor'; 
moor      = 'SW30';
SW30.name = 'SW30';

% --------------------------------------------------------------
 
% load SW30-SBE37-4850.asc';
S4850 = read_sbe('SW30-SBE37-4850.asc','tcp',SW30.name,SW30.Zsens(2));

% load SW30-SBE37-4841.asc;
S4841 = read_sbe('SW30-SBE37-4841.asc','tcp',SW30.name,SW30.Zsens(3));

% load SW30-SBE37-4842.asc;
S4842 = read_sbe('SW30-SBE37-4842.asc','tcp',SW30.name,SW30.Zsens(4));

% load SW30-SBE37-4843.asc;
S4843 = read_sbe('SW30-SBE37-4843.asc','tcp',SW30.name,SW30.Zsens(5));

% load SW30-SBE37-4844.asc;
S4844 = read_sbe('SW30-SBE37-4844.asc','tcp',SW30.name,SW30.Zsens(6));

% load SW30-SBE37-4845.asc;
S4845 = read_sbe('SW30-SBE37-4845.asc','tcp',SW30.name,SW30.Zsens(7));

% load SW30-SBE37-4846.asc;
S4846 = read_sbe('SW30-SBE37-4846.asc','tcp',SW30.name,SW30.Zsens(8));

% load SW30-SBE37-4847.asc;
S4847 = read_sbe('SW30-SBE37-4847.asc','tcp',SW30.name,SW30.Zsens(9));

% load SW30-SBE37-4849.asc;
S4849 = read_sbe('SW30-SBE37-4849.asc','tcp',SW30.name,SW30.Zsens(10));

% load SW30-SBE37-4851.asc;
S4851 = read_sbe('SW30-SBE37-4851.asc','tcp',SW30.name,SW30.Zsens(11));

% load SW30-T0289.asc;
T0289 = read_tpod('SW30-T0289.asc',SW30.name,SW30.Zsens(13));
 
 
% -----------------------------------------
% Should we compensate the depths to the mean?

% pmean = mean(S4850.p);
%% pdiff = pmean - S4850.dep;
%% S4850.dep = pmean;

% ndx = find (S4850.mday > st_date &  S4850.mday < end_date );
% S4850.mday = S4850.mday(ndx);
% S4850.t   = S4850.t(ndx);
% S4850.p  = S4850.p(ndx);
 
% etc.....
% -----------------------------------------------------------------------------
   
save  SW30  SW30 T0289 S4850 S4841 S4842 S4843 S4844 S4845 S4846 S4847 S4849 S4851;

% -------------------------------------------------------------------------------

 if (plotem)

   figure(1); clf
   subplot(311)
   plot(S4850.mday,S4850.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_4850  Temperature at %6.2fm Z',SW30.type, S4850.moor,S4850.dep);
   title(S,'interpreter','none');

   subplot(312)
   plot(S4850.mday,S4850.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_4850  Pressure',SW30.type,S4850.moor);
   title(S,'interpreter','none');

   subplot(313)
   plot(S4850.mday,S4850.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_4850  Conductivity',SW30.type,S4850.moor);
   title(S,'interpreter','none');
   %%%  print -dps -Phpbw

   % ---------------------------------------------------------

   figure(3); clf
   subplot(311)
   plot(S4842.mday,S4842.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_4842  Temperature at %6.2fm Z',SW30.type, S4842.moor,S4842.dep);
   title(S,'interpreter','none');
 
   subplot(312)
   plot(S4842.mday,S4842.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_4842  Pressure',SW30.type,S4842.moor);
   title(S,'interpreter','none');

   
   subplot(313)
   plot(S4842.mday,S4842.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_4842  Conductivity',SW30.type,S4842.moor);
   title(S,'interpreter','none');
   %%%  print -dps -Phpbw

   % ---------------------------------------------------------

   figure(2); clf
   subplot(311)
   plot(S4841.mday,S4841.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_4841  Temperature at %6.2fm Z',SW30.type, S4841.moor,S4841.dep);
   title(S,'interpreter','none');
 
   subplot(312)
   plot(S4841.mday,S4841.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_4841  Pressure',SW30.type,S4841.moor);
   title(S,'interpreter','none');

   
   subplot(313)
   plot(S4841.mday,S4841.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_4841  Conductivity',SW30.type,S4841.moor);
   title(S,'interpreter','none');
   %%%  print -dps -Phpbw

    % ---------------------------------------------------------

   figure(4); clf
   subplot(311)
   plot(S4843.mday,S4843.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_4843  Temperature at %6.2fm Z',SW30.type, S4843.moor,S4843.dep);
   title(S,'interpreter','none');
 
   subplot(312)
   plot(S4843.mday,S4843.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_4843  Pressure',SW30.type,S4843.moor);
   title(S,'interpreter','none');

   
   subplot(313)
   plot(S4843.mday,S4843.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_4843  Conductivity',SW30.type,S4843.moor);
   title(S,'interpreter','none');
   %%%  print -dps -Phpbw

   % ---------------------------------------------------------

   figure(5); clf
   subplot(311)
   plot(S4844.mday,S4844.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_4844  Temperature at %6.2fm Z',SW30.type, S4844.moor,S4844.dep);
   title(S,'interpreter','none');
 
   subplot(312)
   plot(S4844.mday,S4844.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_4844  Pressure',SW30.type,S4844.moor);
   title(S,'interpreter','none');

   
   subplot(313)
   plot(S4844.mday,S4844.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_4844  Conductivity',SW30.type,S4844.moor);
   title(S,'interpreter','none');
   %%%  print -dps -Phpbw

   % ---------------------------------------------------------

   figure(6); clf
   subplot(311)
   plot(S4845.mday,S4845.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_4845  Temperature at %6.2fm Z',SW30.type, S4845.moor,S4845.dep);
   title(S,'interpreter','none');
 
   subplot(312)
   plot(S4845.mday,S4845.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_4845  Pressure',SW30.type,S4845.moor);
   title(S,'interpreter','none');

   
   subplot(313)
   plot(S4845.mday,S4845.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_4845  Conductivity',SW30.type,S4845.moor);
   title(S,'interpreter','none');
   %%%  print -dps -Phpbw

   % ---------------------------------------------------------

   figure(7); clf
   subplot(311)
   plot(S4846.mday,S4846.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_4846  Temperature at %6.2fm Z',SW30.type, S4846.moor,S4846.dep);
   title(S,'interpreter','none');
 
   subplot(312)
   plot(S4846.mday,S4846.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_4846  Pressure',SW30.type,S4846.moor);
   title(S,'interpreter','none');

   
   subplot(313)
   plot(S4846.mday,S4846.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_4846  Conductivity',SW30.type,S4846.moor);
   title(S,'interpreter','none');
   %%%  print -dps -Phpbw

   % ---------------------------------------------------------

   figure(8); clf
   subplot(311)
   plot(S4847.mday,S4847.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_4847  Temperature at %6.2fm Z',SW30.type, S4847.moor,S4847.dep);
   title(S,'interpreter','none');
 
   subplot(312)
   plot(S4847.mday,S4847.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_4847  Pressure',SW30.type,S4847.moor);
   title(S,'interpreter','none');

   
   subplot(313)
   plot(S4847.mday,S4847.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_4847  Conductivity',SW30.type,S4847.moor);
   title(S,'interpreter','none');
   %%%  print -dps -Phpbw

   % ---------------------------------------------------------

   figure(9); clf
   subplot(311)
   plot(S4849.mday,S4849.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_4849  Temperature at %6.2fm Z',SW30.type, S4849.moor,S4849.dep);
   title(S,'interpreter','none');
 
   subplot(312)
   plot(S4849.mday,S4849.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_4849  Pressure',SW30.type,S4849.moor);
   title(S,'interpreter','none');

   
   subplot(313)
   plot(S4849.mday,S4849.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_4849  Conductivity',SW30.type,S4849.moor);
   title(S,'interpreter','none');
   %%%  print -dps -Phpbw

   % ---------------------------------------------------------

   figure(10); clf
   subplot(311)
   plot(S4851.mday,S4851.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_4851  Temperature at %6.2fm Z',SW30.type, S4851.moor,S4851.dep);
   title(S,'interpreter','none');
 
   subplot(312)
   plot(S4851.mday,S4851.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_4851  Pressure',SW30.type,S4851.moor);
   title(S,'interpreter','none');

   
   subplot(313)
   plot(S4851.mday,S4851.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_4851  Conductivity',SW30.type,S4851.moor);
   title(S,'interpreter','none');
   %%%  print -dps -Phpbw

   % ---------------------------------------------------------

   figure(11); clf
   plot(T0289.mday,T0289.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   xlabel('Date');
   S = sprintf('%s %s_T0289  Temperature at %6.2fm Z',SW30.type,T0289.moor,T0289.dep);
   title(S,'interpreter','none');


end

% --------------------------------------------------------------------------------
