% -------------------------------------------------------------------
%   load_SW31
%
%    load data from sensors on mooring SW31 
%    
%
% SW31			83	01 aug 11:58	Env. Mooring	
%					39 02.549  73 03.214
%	Mini-T	290	1	 	lost	
%	SBE37	399	12 -ends 1 Sept	SW31-SBE37-0399.cap
%	SBE39	26	21	 SW31-SBE39-0026.cap
%	SBE37	1134	31	 SW31-SBE37-1134.cap
%	SBE39	6	42	 SW31-SBE39-0006.cap
%	SBE37	1136	53	 SW31-SBE37-1136.cap
%	SBE39	8	64	 SW31-SBE39-0008.cap
%	SBE37	397	75 -ends 2 Sept	SW31-SBE37-0397.cap
%				
% 
%   SBE37-0399  has temp, conductivity, and pressure 
%   SBE37-1134  has temp and conductivity 
%   SBE37-1136  has temp and conductivity 
%   ALL SBE39's here have temp ONLY 
% 
% ------------------------------------------------------------------------

plotem = 1;

SW31.Zsens   = [1 12 21 31 42 53 64 75 ];
SW31.dep  = 83;
SW31.latd = 39; 
SW31.latm = 02.549; 
SW31.lond = 73; 
SW31.lonm = 03.214;
SW31.type = 'EnvMoor'; 
SW31.name = 'SW31';
 


% SBE37  0399    -   has temp,conductivity and pressure
% load SW31-SBE37-0399.asc;
S0399 = read_sbe('SW31-SBE37-0399.asc','tcp',SW31.name,SW31.Zsens(2));

% SBE39 0026   -   has temp
% load SW31-SBE39-0026.asc;
S0026 = read_sbe('SW31-SBE39-0026.asc','t',SW31.name,SW31.Zsens(3));

% SBE37 1134   -   has temp and conductivity
% load SW31-SBE37-1134.asc;
S1134 = read_sbe('SW31-SBE37-1134.asc','tc',SW31.name,SW31.Zsens(4));

% SBE39 0006   -   has temp
% load SW31-SBE39-0006.asc;
S0006 = read_sbe('SW31-SBE39-0006.asc','t',SW31.name,SW31.Zsens(5));

% SBE37 1136   -   has temp, conductivity
% load SW31-SBE37-1136.asc;
S1136 = read_sbe('SW31-SBE37-1136.asc','tc',SW31.name,SW31.Zsens(6));

% SBE39 0008   -   has temp
% load SW31-SBE39-0008.asc;
S0008 = read_sbe('SW31-SBE39-0008.asc','t',SW31.name,SW31.Zsens(5));

% SBE37 0397   -   has temp, conductivity and pressure
% load SW31-SBE37-0397.asc;
S0397 = read_sbe('SW31-SBE37-0397.asc','tcp',SW31.name,SW31.Zsens(8)); 


 
% -----------------------------------------
 
% Should we compensate the depths to the mean?
% pmean = mean(S0399.p);
%% pdiff = pmean - S0399.dep;
%% S0399.dep = pmean;

% Use these to sync data...
%% st_date = datenum(0289,7,30,19,20,00);
%% end_date = datenum(0289,9,9,22,20,00);

% ndx = find (S0399.mday > st_date &  S0399.mday < end_date );
% S0399.mday = S0399.mday(ndx);
% S0399.t   = S0399.t(ndx);
% S0399.p  = S0399.p(ndx);

% ndx = find (S0026.mday > st_date &  S0026.mday < end_date );
% S0026.mday = S0026.mday(ndx);
% S0026.t   = S0026.t(ndx);
% S0026.p  = S0026.p(ndx);
 
% ndx = find (S1134.mday > st_date &  S1134.mday < end_date );
% S1134.mday = S1134.mday(ndx);
% S1134.t   = S1134.t(ndx);
% S1134.p  = S1134.p(ndx);

% ndx = find (S0006.mday > st_date &  S0006.mday < end_date );
% S0006.mday = S0006.mday(ndx);
% S0006.t   = S0006.t(ndx);
% S0006.p  = S0006.p(ndx);
 
% ndx = find (S1136.mday > st_date &  S1136.mday < end_date );
% S1136.mday = S1136.mday(ndx);
% S1136.t   = S1136.t(ndx);
% S1136.p  = S1136.p(ndx);

% ndx = find (S0008.mday > st_date &  S0008.mday < end_date );
% S0008.mday = S0008.mday(ndx);
% S0008.t   = S0008.t(ndx);
% S0008.p  = S0008.p(ndx);

% ndx = find (S0397.mday > st_date &  S0397.mday < end_date );
% S0397.mday = S0397.mday(ndx);
% S0397.t   = S0397.t(ndx);
% S0397.p  = S0397.p(ndx);

% --------------------------------------------------------------------------
 
   
save  SW31  SW31 S0399 S0026 S1134 S0006 S1136 S0008 S0397;

% -------------------------------------------------------------------------------
 
if (plotem)
   figure(1); clf
   subplot(311)
   plot(S0399.mday,S0399.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0399  Temperature at %6.2fm Z',SW31.type, S0399.moor,S0399.dep);
   title(S,'interpreter','none');

   subplot(312)
   plot(S0399.mday,S0399.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_0399  Pressure',SW31.type,S0399.moor);
   title(S,'interpreter','none');

   subplot(313)
   plot(S0399.mday,S0399.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_0399  Conductivity',SW31.type,S0399.moor);
   title(S,'interpreter','none');
  
   figure(2); clf
   plot(S0026.mday,S0026.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0026  Temperature at %6.2fm Z',SW31.type, S0026.moor,S0026.dep);
   title(S,'interpreter','none');
  
   figure(3); clf
   subplot(211)
   plot(S1134.mday,S1134.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_1134  Temperature at %6.2fm Z',SW31.type, S1134.moor,S1134.dep);
   title(S,'interpreter','none');
 
   
   subplot(212)
   plot(S1134.mday,S1134.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_1134  Conductivity',SW31.type,S1134.moor);
   title(S,'interpreter','none');
  
   figure(4); clf
   plot(S0006.mday,S0006.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0006  Temperature at %6.2fm Z',SW31.type, S0006.moor,S0006.dep);
   title(S,'interpreter','none');
 
   figure(5); clf
   subplot(211)
   plot(S1136.mday,S1136.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_1136  Temperature at %6.2fm Z',SW31.type, S1136.moor,S1136.dep);
   title(S,'interpreter','none')

   
   subplot(212)
   plot(S1136.mday,S1136.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_1136  Conductivity',SW31.type,S1136.moor);
   title(S,'interpreter','none');
  
   figure(6); clf
   plot(S0008.mday,S0008.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0008  Temperature at %6.2fm Z',SW31.type, S0008.moor,S0008.dep);
   title(S,'interpreter','none');
 
   figure(7); clf
   subplot(311)
   plot(S0397.mday,S0397.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0397  Temperature at %6.2fm Z',SW31.type, S0397.moor,S0397.dep);
   title(S,'interpreter','none');
 
   subplot(312)
   plot(S0397.mday,S0397.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_0397  Pressure',SW31.type,S0397.moor);
   title(S,'interpreter','none');

   
   subplot(313)
   plot(S0397.mday,S0397.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_0397  Conductivity',SW31.type,S0397.moor);
   title(S,'interpreter','none');
   %%%  print -dps -Phpbw
end
 
% -----------------------------------------
