% -------------------------------------------------------------------
%   load_SW33
%
%    load data from sensors on mooring SW33 
%        ignoring the adcp for now
%
% SW33			80	28 jul 20:29	Env. Mooring	
%					39 12.290  72 54.705
%	Mini-T	2070	1		lost	
%	SBE37	400	12	 -ends 29 Aug	SW33-SBE37-0400.cap
%	SBE39	14	21	  -ends 2 Sept	SW33-SBE39-0014.cap
%	SBE37	1139	31	 -ends 6 Sept	SW33-SBE37-1139.cap
%	SBE39	16	42	-0-	no data	SW33-SBE39-0016.cap
%	SBE37	1140	53	  -ends 6 Sept	SW33-SBE37-1140.cap
%	SBE39	17	64	 		SW33-SBE39-0017.cap
%	SBE37	404	75	  -ends 29 Aug	SW33-SBE37-0404.cap
%	ADCP	705	75	 		SW033000.000 & .001
%	Mini-T	2075	77.5	 		SW33-T2075.dat
%
% 
%   SBE37 0400 and 0404 have temp, conductivity, and pressure
%   SBE37 1139 and 1140 have temp and conductivity 
%   All SBE39's have temperature only
%        SBE39 #0016 has no data
%
% ------------------------------------------------------------------------

plotem = 1;

SW33.Zsens   = [1 12 21 31 42 53 64 75 75 77.5  ];
SW33.dep  = 80;
SW33.latd = 39; 
SW33.latm = 12.290; 
SW33.lond = 72; 
SW33.lonm = 54.705;
SW33.type = 'EnvMoor'; 
SW33.name = 'SW33';
 
% Use these to sync data...
%% st_date = datenum(2075,7,30,19,20,00);
%% end_date = datenum(2075,9,9,22,20,00);


% SBE37  0400    -   has temp,conductivity and pressure
% load SW33-SBE37-0400.asc;
S0400 = read_sbe('SW33-SBE37-0400.asc','tcp',SW33.name,SW33.Zsens(2));

% SBE39 0014   -   has temp only
% load SW33-SBE39-0014.asc;
S0014 = read_sbe('SW33-SBE39-0014.asc','t',SW33.name,SW33.Zsens(3));

% SBE37 1139   -   has temp and conductivity 
% load SW33-SBE37-1139.asc;
S1139 = read_sbe('SW33-SBE37-1139.asc','tc',SW33.name,SW33.Zsens(4));

% SBE37 0016   -   has NO DATA
% load SW33-SBE39-0016.asc;   	% Did not sample

% SBE37 1140   -   has temp and conductivity
% load SW33-SBE37-1140.asc;
S1140 = read_sbe('SW33-SBE37-1140.asc','tc',SW33.name,SW33.Zsens(6));

% SBE39 0017   -   has temp ONLY
% load SW33-SBE39-0017.asc;
S0017 = read_sbe('SW33-SBE39-0017.asc','t',SW33.name,SW33.Zsens(7));

% SBE37 0404   -   has temp, conductivity and pressure
% load SW33-SBE37-0404.asc;
S0404 = read_sbe('SW33-SBE37-0404.asc','tcp',SW33.name,SW33.Zsens(8));

% tpod
% load SW33-T2075.asc;
T2075 = read_tpod('SW33-T2075.asc',SW33.name,SW33.Zsens(9)); 

% -----------------------------------------
 
% Should we compensate the depths to the mean?
% pmean = mean(S0400.p);
%% pdiff = pmean - S0400.dep;
%% S0400.dep = pmean;

% ndx = find (S0400.mday > st_date &  S0400.mday < end_date );
% S0400.mday = S0400.mday(ndx);
% S0400.t   = S0400.t(ndx);
% S0400.p  = S0400.p(ndx);

% ndx = find (S0014.mday > st_date &  S0014.mday < end_date );
% S0014.mday = S0014.mday(ndx);
% S0014.t   = S0014.t(ndx);
% S0014.p  = S0014.p(ndx);

% ndx = find (S1139.mday > st_date &  S1139.mday < end_date );
% S1139.mday = S1139.mday(ndx);
% S1139.t   = S1139.t(ndx);
% S1139.p  = S1139.p(ndx);

% % ndx = find (S0016.mday > st_date &  S0016.mday < end_date );
% % S0016.mday = S0016.mday(ndx);
% % S0016.t   = S0016.t(ndx);
% % S0016.p  = S0016.p(ndx);

% ndx = find (S1140.mday > st_date &  S1140.mday < end_date );
% S1140.mday = S1140.mday(ndx);
% S1140.t   = S1140.t(ndx);
% S1140.p  = S1140.p(ndx);

% ndx = find (S0017.mday > st_date &  S0017.mday < end_date );
% S0017.mday = S0017.mday(ndx);
% S0017.t   = S0017.t(ndx);
% S0017.p  = S0017.p(ndx);

% ndx = find (S0404.mday > st_date &  S0404.mday < end_date );
% S0404.mday = S0404.mday(ndx);
% S0404.t   = S0404.t(ndx);
% S0404.p  = S0404.p(ndx);

% ndx = find (T2075.mday > st_date &  T2075.mday < end_date );
% T2075.mday = T2075.mday(ndx);
% T2075.t   = T2075.t(ndx); 

% -----------------------------------------------------------------------------
   
save  SW33  SW33 T2075 S0400 S0014 S1139 S1140 S0017 S0404;

% -------------------------------------------------------------------------------
 if (plotem)
   figure(1); clf
   subplot(311)
   plot(S0400.mday,S0400.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0400  Temperature at %6.2fm Z',SW33.type, S0400.moor,S0400.dep);
   title(S,'interpreter','none');

   subplot(312)
   plot(S0400.mday,S0400.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_0400  Pressure',SW33.type,S0400.moor);
   title(S,'interpreter','none');

   subplot(313)
   plot(S0400.mday,S0400.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_0400  Conductivity',SW33.type,S0400.moor);
   title(S,'interpreter','none');
   
   figure(2); clf
   plot(S0014.mday,S0014.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0014  Temperature at %6.2fm Z',SW33.type, S0014.moor,S0014.dep);
   title(S,'interpreter','none'); 
 
   figure(3); clf
   subplot(211)
   plot(S1139.mday,S1139.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_1139  Temperature at %6.2fm Z',SW33.type, S1139.moor,S1139.dep);
   title(S,'interpreter','none');
 
   
   subplot(212)
   plot(S1139.mday,S1139.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_1139  Conductivity',SW33.type,S1139.moor);
   title(S,'interpreter','none');
  
% if (plotem)
%    figure(4); clf
%    plot(S0016.mday,S0016.t); grid
%    datetick
%    set(gca,'ylim',[5 27]);
%    ylabel('temp (C)');
%    S = sprintf('%s %s_SBE39_0016  Temperature at %6.2fm Z',SW33.type, S0016.moor,S0016.dep);
%    title(S,'interpreter','none');
%  
% end
 
   figure(5); clf
   subplot(211)
   plot(S1140.mday,S1140.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_1140  Temperature at %6.2fm Z',SW33.type, S1140.moor,S1140.dep);
   title(S,'interpreter','none');
   
   subplot(212)
   plot(S1140.mday,S1140.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_1140  Conductivity',SW33.type,S1140.moor);
   title(S,'interpreter','none');
 
   figure(6); clf
   plot(S0017.mday,S0017.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0017  Temperature at %6.2fm Z',SW33.type, S0017.moor,S0017.dep);
   title(S,'interpreter','none');
 
   figure(7); clf
   subplot(311)
   plot(S0404.mday,S0404.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0404  Temperature at %6.2fm Z',SW33.type, S0404.moor,S0404.dep);
   title(S,'interpreter','none');
 
   subplot(312)
   plot(S0404.mday,S0404.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_0404  Pressure',SW33.type,S0404.moor);
   title(S,'interpreter','none');

   
   subplot(313)
   plot(S0404.mday,S0404.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_0404  Conductivity',SW33.type,S0404.moor);
   title(S,'interpreter','none');
 
  figure(8); clf
  plot(T2075.mday,T2075.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date');
  S = sprintf('%s %s_T2075  Temperature at %6.2fm Z',SW33.type,T2075.moor,T2075.dep);
  title(S,'interpreter','none');
end

