% -------------------------------------------------------------------
%   load_SW34
%
%    load data from sensors on mooring SW34 
%        ignoring the adcp for now
%
% SW34			124	27 jul 14:21	Env. Mooring	
% 					38 56.37  72 52.566
%	Mini-T	2071	1			SW34-T2071.dat
%	SBE37	396	12	  -ends 28 Aug	SW34-SBE37-0396.cap
%	SBE39	18	21	  -ends 10 Sept	SW34-SBE39-0018.cap
%	SBE37	716	31	  -ends 4 Sept	SW34-SBE37-0716.cap
%	SBE39	19	42	  -ends 10 Sept	SW34-SBE39-0019.cap
%	SBE37	458	53	  -ends 4 Sept	SW34-SBE37-0458.cap
%	SBE39	20	64	  -ends 10 Sept	SW34-SBE39-0020.cap
%	SBE37	1132	75	  -ends 3 Sept	SW34-SBE37-1132.cap
%	SBE39	21	86	  -ends 10 Sept	SW34-SBE39-0021.cap
%	SBE37	715	97	  -ends 4 Sept	SW34-SBE37-0715.cap
%	SBE39	24	106	 		SW34-SBD39-0024.dmp
%	SBE37	403	118	  -ends 28 Aug	SW34-SBD37-0403.cap
%	Mini-T	2072	121.5			SW34-T2072.DAT
% 
%				
% 
%   SBE37 0396, 0403  have temp, conductivity, and pressure 
%   SBE37 0715, 0716, 0458, 1132 have temp and conductivity 
%   SBE39's have temperature ONLY
%
%
%
% ------------------------------------------------------------------------
 
plotem = 1;

 
SW34.Zsens   = [1 12 21 31 42 53 64 75 86 97 106 118 121.5  ];
SW34.dep  = 124;
SW34.latd = 38; 
SW34.latm = 56.37; 
SW34.lond = 72; 
SW34.lonm = 52.566;
SW34.type = 'EnvMoor'; 
SW34.name = 'SW34';
 

% load SW34-T2071.asc;
T2071 = read_tpod('SW34-T2071.asc',SW34.name,SW34.Zsens(1));


% SBE37  0396    -   has temp,conductivity and pressure
% load SW34-SBE37-0396.asc;
%  day/month in wrong column format, reading by hand
%%%%%% S0396 = read_sbe('SW34-SBE37-0396.asc','tcp',SW34.name,SW34.Zsens(2));
load SW34-SBE37-0396.asc;
        Dat = SW34_SBE37_0396;
        S0396.t    = Dat(:,1);
        S0396.p    = Dat(:,3);
        S0396.con  = Dat(:,2);
        S0396.dep  = SW34.Zsens(2);
        S0396.yr   = Dat(:,6);
        S0396.mon  = Dat(:,4);   % wrong order for function
        S0396.day  = Dat(:,5);  % wrong order for function
        S0396.hr   = Dat(:,7);
        S0396.min  = Dat(:,8);
        S0396.sec  = Dat(:,9);
        S0396.moor = SW34.name;
        S0396.mday = datenum(S0396.yr,S0396.mon,S0396.day,S0396.hr,S0396.min,S0396.sec );


% SBE39 0018   -   has temp  
% load SW34-SBE39-0018.asc;
S0018 = read_sbe('SW34-SBE39-0018.asc','t',SW34.name,SW34.Zsens(3));


% SBE37 0716   -   has temp, conductivity 
% load SW34-SBE37-0716.asc;
S0716 = read_sbe('SW34-SBE37-0716.asc','tc',SW34.name,SW34.Zsens(4));


% SBE39 0019   -   has temp
% load SW34-SBE39-0019.asc;
S0019 = read_sbe('SW34-SBE39-0019.asc','t',SW34.name,SW34.Zsens(5));


% SBE37 0458   -   has temp, conductivity 
% load SW34-SBE37-0458.asc;
S0458 = read_sbe('SW34-SBE37-0458.asc','tc',SW34.name,SW34.Zsens(6));


% SBE39 0020   -   has temp
% load SW34-SBE39-0020.asc;
S0020 = read_sbe('SW34-SBE39-0020.asc','t',SW34.name,SW34.Zsens(7));


% SBE37 1132   -   has temp, conductivity 
% load SW34-SBE37-1132.asc;
S1132 = read_sbe('SW34-SBE37-1132.asc','tc',SW34.name,SW34.Zsens(8));


% SBE39 0021   -   has temp
% load SW34-SBE39-0021.asc;
S0021 = read_sbe('SW34-SBE39-0021.asc','t',SW34.name,SW34.Zsens(9));


% SBE37 0715   -   has temp, conductivity
% load SW34-SBE37-0715.asc;
S0715 = read_sbe('SW34-SBE37-0715.asc','tc',SW34.name,SW34.Zsens(10));


% SBE39 0024   -   has temp
% load SW34-SBE39-0024.asc;
S0024 = read_sbe('SW34-SBE39-0024.asc','t',SW34.name,SW34.Zsens(11));


% SBE37 0403   -   has temp, conductivity and pressure
% load SW34-SBE37-0403.asc;
S0403 = read_sbe('SW34-SBE37-0403.asc','tcp',SW34.name,SW34.Zsens(12));

% tpod has temp
% load SW34-T2072.asc;
T2072 = read_tpod('SW34-T2072.asc',SW34.name,SW34.Zsens(13));


% -----------------------------------------
 
% Should we compensate the depths to the mean?
% pmean = mean(S0396.p);
%% pdiff = pmean - S0396.dep;
%% S0396.dep = pmean;

% Use these to sync data...
%% st_date = datenum(2072,7,30,19,20,00);
%% end_date = datenum(2072,9,9,22,20,00);

% ndx = find (S0396.mday > st_date &  S0396.mday < end_date );
% S0396.mday = S0396.mday(ndx);
% S0396.t   = S0396.t(ndx);
% S0396.p  = S0396.p(ndx);

% ndx = find (S0018.mday > st_date &  S0018.mday < end_date );
% S0018.mday = S0018.mday(ndx);
% S0018.t   = S0018.t(ndx);
% S0018.p  = S0018.p(ndx);

% ndx = find (S0716.mday > st_date &  S0716.mday < end_date );
% S0716.mday = S0716.mday(ndx);
% S0716.t   = S0716.t(ndx);
% S0716.p  = S0716.p(ndx);

% ndx = find (S0019.mday > st_date &  S0019.mday < end_date );
% S0019.mday = S0019.mday(ndx);
% S0019.t   = S0019.t(ndx);
% S0019.p  = S0019.p(ndx);

% ndx = find (S0458.mday > st_date &  S0458.mday < end_date );
% S0458.mday = S0458.mday(ndx);
% S0458.t   = S0458.t(ndx);
% S0458.p  = S0458.p(ndx);

% ndx = find (S0020.mday > st_date &  S0020.mday < end_date );
% S0020.mday = S0020.mday(ndx);
% S0020.t   = S0020.t(ndx);
% S0020.p  = S0020.p(ndx);

% ndx = find (S1132.mday > st_date &  S1132.mday < end_date );
% S1132.mday = S1132.mday(ndx);
% S1132.t   = S1132.t(ndx);
% S1132.p  = S1132.p(ndx);

% ndx = find (S0021.mday > st_date &  S0021.mday < end_date );
% S0021.mday = S0021.mday(ndx);
% S0021.t   = S0021.t(ndx);
% S0021.p  = S0021.p(ndx);

% ndx = find (S0715.mday > st_date &  S0715.mday < end_date );
% S0715.mday = S0715.mday(ndx);
% S0715.t   = S0715.t(ndx);
% S0715.p  = S0715.p(ndx);

% ndx = find (S0024.mday > st_date &  S0024.mday < end_date );
% S0024.mday = S0024.mday(ndx);
% S0024.t   = S0024.t(ndx);
% S0024.p  = S0024.p(ndx);
 
% ndx = find (S0403.mday > st_date &  S0403.mday < end_date );
% S0403.mday = S0403.mday(ndx);
% S0403.t   = S0403.t(ndx);
% S0403.p  = S0403.p(ndx);
 
% ndx = find (T2071.mday > st_date &  T2071.mday < end_date );
% T2071.mday = T2071.mday(ndx);
% T2071.t   = T2071.t(ndx); 

% ndx = find (T2072.mday > st_date &  T2072.mday < end_date );
% T2072.mday = T2072.mday(ndx);
% T2072.t   = T2072.t(ndx); 


% -----------------------------------------------------------------------------
   
save  SW34  SW34 T2071 T2072 S0396 S0018 S0716 S0019 S0458 S0020 S1132 S0021 S0715 S0024 S0403;

% -------------------------------------------------------------------------------
 
if (plotem)
   figure(1); clf
   subplot(311)
   plot(S0396.mday,S0396.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0396  Temperature at %6.2fm Z',SW34.type, S0396.moor,S0396.dep);
   title(S,'interpreter','none');

   subplot(312)
   plot(S0396.mday,S0396.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_0396  Pressure',SW34.type,S0396.moor);
   title(S,'interpreter','none');

   subplot(313)
   plot(S0396.mday,S0396.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_0396  Conductivity',SW34.type,S0396.moor);
   title(S,'interpreter','none');
   
   figure(2); clf
   plot(S0018.mday,S0018.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0018  Temperature at %6.2fm Z',SW34.type, S0018.moor,S0018.dep);
   title(S,'interpreter','none');
  
   figure(3); clf
   subplot(211)
   plot(S0716.mday,S0716.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0716  Temperature at %6.2fm Z',SW34.type, S0716.moor,S0716.dep);
   title(S,'interpreter','none');
 
   subplot(212)
   plot(S0716.mday,S0716.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_0716  Conductivity',SW34.type,S0716.moor);
   title(S,'interpreter','none');
  
   figure(4); clf
   plot(S0019.mday,S0019.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0019  Temperature at %6.2fm Z',SW34.type, S0019.moor,S0019.dep);
   title(S,'interpreter','none');
  
   figure(5); clf
   subplot(211)
   plot(S0458.mday,S0458.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0458  Temperature at %6.2fm Z',SW34.type, S0458.moor,S0458.dep);
   title(S,'interpreter','none');
  
   subplot(212)
   plot(S0458.mday,S0458.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_0458  Conductivity',SW34.type,S0458.moor);
   title(S,'interpreter','none');
  
   figure(6); clf
   plot(S0020.mday,S0020.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0020  Temperature at %6.2fm Z',SW34.type, S0020.moor,S0020.dep);
   title(S,'interpreter','none');
 
   figure(7); clf
   subplot(211)
   plot(S1132.mday,S1132.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_1132  Temperature at %6.2fm Z',SW34.type, S1132.moor,S1132.dep);
   title(S,'interpreter','none');
  
   subplot(212)
   plot(S1132.mday,S1132.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_1132  Conductivity',SW34.type,S1132.moor);
   title(S,'interpreter','none');
  
   figure(8); clf
   plot(S0021.mday,S0021.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0021  Temperature at %6.2fm Z',SW34.type, S0021.moor,S0021.dep);
   title(S,'interpreter','none');
 
   figure(9); clf
   subplot(211)
   plot(S0715.mday,S0715.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0715  Temperature at %6.2fm Z',SW34.type, S0715.moor,S0715.dep);
   title(S,'interpreter','none');

   
   subplot(212)
   plot(S0715.mday,S0715.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_0715  Conductivity',SW34.type,S0715.moor);
   title(S,'interpreter','none');
 
   figure(10); clf
   plot(S0024.mday,S0024.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0024  Temperature at %6.2fm Z',SW34.type, S0024.moor,S0024.dep);
   title(S,'interpreter','none');
 
   figure(11); clf
   subplot(311)
   plot(S0403.mday,S0403.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0403  Temperature at %6.2fm Z',SW34.type, S0403.moor,S0403.dep);
   title(S,'interpreter','none');
 
   subplot(312)
   plot(S0403.mday,S0403.p); grid
   axis('ij');
   datetick
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_0403  Pressure',SW34.type,S0403.moor);
   title(S,'interpreter','none');

   
   subplot(313)
   plot(S0403.mday,S0403.con); grid
   axis('ij');
   datetick
   set(gca,'ylim',[3 6]);
   ylabel('Conductivity'); xlabel('date')
   S = sprintf('%s %s_SBE37_0403  Conductivity',SW34.type,S0403.moor);
   title(S,'interpreter','none');
   
  figure(12); clf
  plot(T2071.mday,T2071.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date');
  S = sprintf('%s %s_T2071  Temperature at %6.2fm Z',SW34.type,T2071.moor,T2071.dep);
  title(S,'interpreter','none');
 
  figure(13); clf
  plot(T2072.mday,T2072.t); grid
  datetick
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  xlabel('Date');
  S = sprintf('%s %s_T2072  Temperature at %6.2fm Z',SW34.type,T2072.moor,T2072.dep);
  title(S,'interpreter','none');
end
