% -------------------------------------------------------------------
%   load_SW47
%
%    load data from sensors on mooring SW47
%
%
% SW47			58	30 jul 20:56	WHOI 224Hz source	
%					39 09.199  73 21.490
%	Mini-T	279	1	 SW47-T0279.dat
%	SBE39	321	14	 SW47-SBE39-0321.cap
%	Mini-T	2086	20	 SW47-T2086.dat
%	Mini-T	276	25	 SW47-T0276.dat
%	Mini-T	2088	30	 SW47-T2088.dat
%	Mini-T	278	35	0 	Flooded, no data  <---	
%	Mini-T	2090	40	 SW47-T2090.dat
%	Mini-T	2037	55.5	 SW47-T2037.dat
%
%
%
% ------------------------------------------------------------------------

plotem = 1;

SW47.Zsens   = [ 1 14 20 25 30 40 55.5];
SW47.dep  = 58;
SW47.latd = 39; 
SW47.latm = 09.199; 
SW47.lond = 73; 
SW47.lonm = 21.490;
SW47.type = 'WHOI 224Hz ';
SW47.name = 'WHOI224';
 
% load SW47-T0279.asc; 
T0279 = read_tpod('SW47-T0279.asc',SW47.name,SW47.Zsens(1));

% temp and pressure
% load SW47-SBE39-0321.asc
S0321 = read_sbe('SW47-SBE39-0321.asc','tp',SW47.name,SW47.Zsens(2));

% load SW47-T2086.asc;
T2086 = read_tpod('SW47-T2086.asc',SW47.name,SW47.Zsens(3));

% load SW47-T0276.asc;
T0276 = read_tpod('SW47-T0276.asc',SW47.name,SW47.Zsens(4));

% load SW47-T2088.asc;
T2088 = read_tpod('SW47-T2088.asc',SW47.name,SW47.Zsens(5));

% load SW47-T2090.asc;
T2090 = read_tpod('SW47-T2090.asc',SW47.name,SW47.Zsens(6));

% load SW47-T2037.asc;
T2037 = read_tpod('SW47-T2037.asc',SW47.name,SW47.Zsens(7));


% --------------------------------------------------------------------------
 
% Should we compensate the depths to the mean?
% pmean = mean(S0321.p);
% pdiff = pmean - S0321.dep;
%% S0321.dep = pmean;

% Use these to sync data... 
%%  st_date = datenum(2006,7,28,19,40,00);
%% end_date = datenum(2006,9,20,9,30,00);

% ndx = find (T0279.mday > st_date &  T0279.mday < end_date );
% T0279.mday = T0279.mday(ndx);
% T0279.t   = T0279.t(ndx);

% ndx = find (S0321.mday > st_date &  S0321.mday < end_date );
% S0321.mday = S0321.mday(ndx);
% S0321.t   = S0321.t(ndx);
% S0321.p  = S0321.p(ndx);

% ndx = find (T2086.mday > st_date &  T2086.mday < end_date );
% T2086.mday = T2086.mday(ndx);
% T2086.t   = T2086.t(ndx);

%% ndx = find (T0276.mday > st_date &  T0276.mday < end_date );
% T0276.mday = T0276.mday(ndx);
% T0276.t   = T0276.t(ndx);

% ndx = find (T2088.mday > st_date &  T2088.mday < end_date );
% T2088.mday = T2088.mday(ndx);
% T2088.t   = T2088.t(ndx);

% ndx = find (T2090.mday > st_date &  T2090.mday < end_date );
% T2090.mday = T2090.mday(ndx);
% T2090.t   = T2090.t(ndx);


% ndx = find (T2037.mday > st_date &  T2037.mday < end_date );
% T2037.mday = T2037.mday(ndx);
% T2037.t   = T2037.t(ndx);

% -------------------------------------------------------------------------------

save  SW47  SW47 S0321 T0279 T2086 T0276 T2088 T2090 T2037  ;
 
% -------------------------------------------------------------------------------


if (plotem) 
  figure(2); clf
  plot(T0279.mday,T0279.t); grid
  datetick
  set(gca,'ylim',[6 28]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T0279  Temperature at %6.2fm Z',SW47.type,T0279.moor,T0279.dep);
  title(S,'interpreter','none');
  
   figure(1); clf
   subplot(211)
   plot(S0321.mday,S0321.t); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('temp (C)');
   S = sprintf('%s %s_SBE39_0321  Temperature at %6.2fm Z',SW47.type, S0321.moor,S0321.dep);
   title(S,'interpreter','none');

   subplot(212)
   plot(S0321.mday,S0321.p); grid
   datetick
   set(gca,'ylim',[5 27]);
   ylabel('Pressure (dbars)'); xlabel('date')
   S = sprintf('%s %s_SBE39_0321  Pressure',SW47.type,S0321.moor);
   title(S,'interpreter','none');
 
  figure(3); clf
  plot(T2086.mday,T2086.t); grid
  datetick
  set(gca,'ylim',[6 28]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2086  Temperature at %6.2fm Z',SW47.type,T2086.moor,T2086.dep);
  title(S,'interpreter','none');
 
 
  figure(4); clf
  plot(T0276.mday,T0276.t); grid
  datetick
  set(gca,'ylim',[6 28]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T0276  Temperature at %6.2fm Z',SW47.type,T0276.moor,T0276.dep);
  title(S,'interpreter','none');
 
  figure(5); clf
  plot(T2088.mday,T2088.t); grid
  datetick
  set(gca,'ylim',[6 28]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2088  Temperature at %6.2fm Z',SW47.type,T2088.moor,T2088.dep);
  title(S,'interpreter','none');
   
  figure(6); clf
  plot(T2090.mday,T2090.t); grid
  datetick
  set(gca,'ylim',[6 28]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2090  Temperature at %6.2fm Z',SW47.type,T2090.moor,T2090.dep);
  title(S,'interpreter','none');
  
  figure(7); clf
  plot(T2037.mday,T2037.t); grid
  datetick
  set(gca,'ylim',[6 28]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2037  Temperature at %6.2fm Z',SW47.type,T2037.moor,T2037.dep);
  title(S,'interpreter','none');
 
end
 


