% --------------------------------------------------------------
%   load_sw54.m
%
%  loads and plots the temperature sensors on the shark (sw54) mooring
% 
% SW54			79	02 aug 14:48	Shark hla/vla	
%			39 01.2516  73 02.9833
%	Mini-T	2048		Lost  		
%	SBE39	242	13.25		SW54-SBD39-0242.cap
%	Mini-T	2047	15.05		SW54-T2047.dat
%	SBE39	22	18.8		SW54-SBD39-0022.cap
%	Mini-T	2051	22.55 - 502 bad values	SW54-T2051.dat
%	SBE39	23	26.3		SW54-SBE39-0023.dmp
%	Mini-T	2096	33.8		SW54-T2096.dat
%	Mini-T	2097	41.3		SW54-T2097.dat
%	Mini-T	2094	56.3		SW54-T2094.dat
%	Mini-T	2095	71.3		SW54-T2095.dat
%	Mini-T	2062	78.5		SW54-T2062.dat
%
%  shark deployed on aug 2, 14:48 Z
%
%  only sensor with pressure is  SBE39 #0242
% ---------------------------------------------------------------

plotem = 1;
printem = 0;

SW54.Zsens = [13.25 15.05 18.8 22.55 26.3 33.8 41.3 56.3 71.3 78.5];
SW54.dep  = 79;
SW54.latd = 39; 
SW54.latm = 1.2516; 
SW54.lond = 73; 
SW54.lonm = 2.9833;
SW54.type = 'Shark ';
moor      = 'SW54';
SW54.name = 'SW54';
 
% ------------------------------------------------------------------


%  0242 has temp and pressure
S0242 = read_sbe('SW54-SBE39-0242.asc','tp',moor,SW54.Zsens(1));

% load SW54-T2047.asc                % 15.05m  
T2047 = read_tpod('SW54-T2047.asc',moor,SW54.Zsens(2));

% SW54-SBE39-0022.asc has temp only       % 18.8m
S0022 = read_sbe('SW54-SBE39-0022.asc','t',moor,SW54.Zsens(3));

% load SW54-T2051.asc                 % 22.55m
T2051 = read_tpod('SW54-T2051.asc',moor,SW54.Zsens(4));

% SW54-SBE39-0023.asc has temp only       % 26.3m
S0023 = read_sbe('SW54-SBE39-0023.asc','t',moor,SW54.Zsens(5));

% load SW54-T2096.asc                 % 33.8m
T2096 = read_tpod('SW54-T2096.asc',moor,SW54.Zsens(6));

% load SW54-T2097.asc                 % 41.3m
T2097 = read_tpod('SW54-T2097.asc',moor,SW54.Zsens(7));

% load SW54-T2094.asc                 % 56.3m 
T2094 = read_tpod('SW54-T2094.asc',moor,SW54.Zsens(8));

% load SW54-T2095.asc                 % 71.3m
T2095 = read_tpod('SW54-T2095.asc',moor,SW54.Zsens(9));

% load SW54-T2062.asc                 % 78.5m 
T2062 = read_tpod('SW54-T2062.asc',moor,SW54.Zsens(10));

 
% ------------------------------------------------------------------
 

save SW54  SW54 S0242 T2047 S0022 T2051 S0023 T2096 T2097 T2094 T2095 T2062;
 
% -------------------------------------------------------------------------


if (plotem)

 figure(1); clf
 subplot(211) 
 plot(S0242.mday,S0242.t); grid
 datetick
 ylabel('temp (C)');
 title('Shark SW54\_SBE39\_0242  Temperature at 13.25m Z');

 subplot(212)
 plot(S0242.mday,S0242.p); grid
 axis('ij');
 datetick
 ylabel('Pressure (dbars)'); xlabel('date')
 title('Shark SW54\_SBE39\_0242  Pressure');

 if(printem)
    print -dps -Phpbw
 end

% -------------------------------------------------------------- 

 figure(2); clf
 plot(S0022.mday,S0022.t); grid
 datetick
 ylabel('temp (C)');
 title('Shark SW54\_SBE39\_0022  Temperature at 18.80m Z');
 
 if(printem)
    print -dps -Phpbw
 end

% --------------------------------------------------------------

figure(3); clf
 plot(S0023.mday,S0023.t); grid
 datetick
 ylabel('temp (C)');
 title('Shark SW54\_SBE39\_0023  Temperature at 26.3m Z');
 
 if(printem)
    print -dps -Phpbw
 end

% -------------------------------------------------------------------------


 figure(4); clf
 plot(T2047.mday,T2047.t); grid
 datetick
 ylabel('temp (C)');
 title('Shark SW54\_T2047  Temperature at 15.05m Z');
 
 if(printem)
    print -dps -Phpbw
 end

% -------------------------------------------------------------------------

 figure(5); clf
 plot(T2051.mday,T2051.t); grid
 datetick
 ylabel('temp (C)');
 title('Shark SW54\_T2051  Temperature at 22.55m Z');
 
 if(printem)
    print -dps -Phpbw
 end

% -------------------------------------------------------------------------

 figure(6); clf
 plot(T2096.mday,T2096.t); grid
 datetick
 ylabel('temp (C)');
 title('Shark SW54\_T2096  Temperature at 33.80m Z');
 
 if(printem)
    print -dps -Phpbw
 end

% -----------------------------------------------------------------------

 figure(7); clf
 plot(T2097.mday,T2097.t); grid
 datetick
 ylabel('temp (C)');
 title('Shark SW54\_T2097  Temperature at 41.30m Z');
 
 if(printem)
    print -dps -Phpbw
 end

% -------------------------------------------------------------------------
 
 figure(8); clf
 plot(T2094.mday,T2094.t); grid
 datetick
 ylabel('temp (C)');
 title('Shark SW54\_T2094  Temperature at 56.30m Z');
 
 if(printem)
    print -dps -Phpbw
 end

% -------------------------------------------------------------------------

 figure(9); clf
 plot(T2095.mday,T2095.t); grid
 datetick
 ylabel('temp (C)');
 title('Shark SW54\_T2095  Temperature at 71.3m Z');
 
 if(printem)
    print -dps -Phpbw
 end

% -------------------------------------------------------------------------


 figure(10); clf
 plot(T2062.mday,T2062.t); grid
 datetick
 ylabel('temp (C)');
 title('Shark SW54\_T2062  Temperature at 78.5m Z');
 
 if(printem)
    print -dps -Phpbw
 end
 

end


% -------------------------------------------------------------------------
% now put them all together..  Using tpods only
%


%% use to sync data  
st_date = datenum(2006,8,2,14,48,00);
end_date = datenum(2006,9,14,12,00,00);
 
combine = 1;
if (combine)

  ndx = find (S0242.mday > st_date &  S0242.mday < end_date );

  T2047.mday = T2047.mday(ndx);
  T2047.t   = T2047.t(ndx);
 
  T2051.mday = T2051.mday(ndx);
  T2051.t   = T2051.t(ndx);
 
  T2096.mday = T2096.mday(ndx);
  T2096.t   = T2096.t(ndx);

  T2097.mday = T2097.mday(ndx);
  T2097.t   = T2097.t(ndx); 

  T2094.mday = T2094.mday(ndx);
  T2094.t   = T2094.t(ndx);

  T2095.mday = T2095.mday(ndx);
  T2095.t   = T2095.t(ndx);

  T2062.mday = T2062.mday(ndx);
  T2062.t   = T2062.t(ndx); 

% -------------------------------------------------------------------------


  Z = SW54.Zsens([2 4 6 7 8 9 10]);

  figure(11); clf

  T = [ T2047.t T2051.t T2096.t T2097.t T2094.t T2095.t T2062.t]';

  pcolor(T2047.mday,Z,T); shading('interp'); axis('ij'); datetick

  hcb = colorbar('v6');
  set(hcb,'position',[.85 .11 .03 .4], 'FontSize',10);
  S = sprintf('Temp (%sC)',char(176) );
  set(get(hcb,'title'),'string', S);
  box on;

  title('Shark SW54 - Temperature on VLA');
  xlabel('Date');
  ylabel('Depth (m)')

end

% -----------------------------------------------------
% pick a date to plot profile...   testing for later
%  must be on even minute
%     say...     8/20 at 0823


Tmat = datenum(2006,8,20,8,23,0);
Tmat = datenum(2006,8,26,20,23,0);
Tmat = datenum(2006,8,14,12,01,0);

ndx = find(Tmat == T2047.mday);

minT = min( min(T));
maxT = max(max(T));

figure(12); clf;
plot(T(:,ndx), Z,'linewidth',2); grid; axis('ij');

set(gca,'xlim',[minT maxT]);
 

% Changed to average every 2 minutes (4 pts)
animate= 0;

if (animate)
    
    if ~exist('profiles','dir'),
          mkdir profiles
    end
    
    cd profiles
    
    for ii=2:2:length(T)-1
     %  for ii=2:2:6   
    
      Tp = mean( [T(:,ii-1) T(:,ii) T(:,ii+1)]');
      
      figure(12); clf;
      
      plot(Tp, Z, 'linewidth',2); grid; axis('ij');
    
      set(gca,'xlim',[minT maxT]);
    
      S = sprintf('Shark Profile on VLA on %s',datestr(T2047.mday(ii)));
      title(S);
      xlabel('Temp (deg C)');
      ylabel('Depth(m)');

      % pause(.5);
      drawnow
      
      Out_dir = sprintf('%s%s',datestr(T2047.mday(ii),5), ...
                                                         datestr(T2047.mday(ii),7) );
         if ~exist(Out_dir,'dir'),
             mkdir(Out_dir);
         end
                                                
         cd(Out_dir);
         
         stime = datestr(T2047.mday(ii),15);
         stime = stime([ 1 2 4 5]);                                        % remove colon from time
         
         Out_file = sprintf('sw54_temp_%s%s_%s',datestr(T2047.mday(ii),5), ...
                                                         datestr(T2047.mday(ii),7),stime ); 
                                                    
          print('-dpng','-r150',Out_file);
          
          cd ..
    
     end
     cd ..
end


% ----------------------------------------------------------------------------------------------


