% -------------------------------------------------------------------
%   load_sw59
%
%    load data from sensors on mooring sw59
%
% SW59			80	31 aug 14:00	Webb – acdc array	
% 					38 16.138  072 51.721
%	SBE37	4284	15.33 -no date in file	SW59-SBE37-4284.cap
%	Mini-T	2301	16.6 			SW59_T2301.dat
%	Mini-T	2299	24.6			SW59_T2297.dat
%	Mini-T	2023	32.6			SW59_T2023.dat
%	Mini-T	2304	40.6			SW59_T2304.dat
%	Mini-T	2300	48.6			SW59_T2300.dat
%	Mini-T	2297	56.6			SW59_T2297.dat
%	Mini-T	2298	64.6			SW59_T2298.dat
%	Mini-T	2049	72.6			SW59_T2049.dat
%
%
%  Need read_tpod.m routine
% ------------------------------------------------------------------------

plotem = 1;           % plot data too?

SW59.Zsens   = [ 15.33 16.6 24.6 32.6 40.6 48.6 56.6 64.6 72.6 ];
SW59.dep  = 80;
SW59.latd = 38;
SW59.latm = 16.138;
SW59.lond = 72;
SW59.lonm = 51.721;
SW59.type = 'ACDC Webb Array';
SW59.name = 'SW59 ACDC';
 
% ------------------------------------------------------------------------
 
% load SW59_T2301.asc;
T2301 = read_tpod('SW59_T2301.asc',SW59.name,SW59.Zsens(2));

% load SW59_T2299.asc;
T2299 = read_tpod('SW59_T2299.asc',SW59.name,SW59.Zsens(3));

% load SW59_T2023.asc;
T2023 = read_tpod('SW59_T2023.asc',SW59.name,SW59.Zsens(4));

% load SW59_T2304.asc;
T2304 = read_tpod('SW59_T2304.asc',SW59.name,SW59.Zsens(5));

% load SW59_T2300.asc;
T2300 = read_tpod('SW59_T2300.asc',SW59.name,SW59.Zsens(6));

% load SW59_T2297.asc;
T2297 = read_tpod('SW59_T2297.asc',SW59.name,SW59.Zsens(7));

% load SW59_T2298.asc;
T2298 = read_tpod('SW59_T2298.asc',SW59.name,SW59.Zsens(8));

% load SW59_T2049.asc;
T2049 = read_tpod('SW59_T2049.asc',SW59.name,SW59.Zsens(9));


% ---------------------------------------------------------------------------
% sync data??? 

% Use these to sync data...
%% st_date = datenum(2006,7,30,19,20,00);
%% end_date = datenum(2006,9,9,22,20,00);

% ndx = find (T2301.mday > st_date &  T2301.mday < end_date );
% T2301.mday = T2301.mday(ndx);
% T2301.t   = T2301.t(ndx);
 
% ndx = find (T2299.mday > st_date &  T2299.mday < end_date );
% T2299.mday = T2299.mday(ndx);
% T2299.t   = T2299.t(ndx);
  
% ndx = find (T2023.mday > st_date &  T2023.mday < end_date );
% T2023.mday = T2023.mday(ndx);
% T2023.t   = T2023.t(ndx);
 
% ndx = find (T2304.mday > st_date &  T2304.mday < end_date );
% T2304.mday = T2304.mday(ndx);
% T2304.t   = T2304.t(ndx);
 
% ndx = find (T2300.mday > st_date &  T2300.mday < end_date );
% T2300.mday = T2300.mday(ndx);
% T2300.t   = T2300.t(ndx);

% ndx = find (T2297.mday > st_date &  T2297.mday < end_date );
% T2297.mday = T2297.mday(ndx);
% T2297.t   = T2297.t(ndx);
 
% ndx = find (T2298.mday > st_date &  T2298.mday < end_date );
% T2298.mday = T2298.mday(ndx);
% T2298.t   = T2298.t(ndx);
 
% ndx = find (T2049.mday > st_date &  T2049.mday < end_date );
% T2049.mday = T2049.mday(ndx);
% T2049.t   = T2049.t(ndx);
 
% -------------------------------------------------------------------------------
% Save data

save  SW59  SW59  T2301 T2299 T2023 T2304 T2300 T2297 T2298 T2049;


% -------------------------------------------------------------------------------
% plotting done here

if (plotem)

  figure(1); clf
  plot(T2301.mday,T2301.t); grid
  datetick;
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2301  Temperature at %6.2fm Z',SW59.type,T2301.moor,T2301.dep);
  title(S,'interpreter','none');


  figure(2); clf
  plot(T2299.mday,T2299.t); grid
  datetick;
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2299  Temperature at %6.2fm Z',SW59.type,T2299.moor,T2299.dep);
  title(S,'interpreter','none');


  figure(3); clf
  plot(T2023.mday,T2023.t); grid
  datetick;
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2023  Temperature at %6.2fm Z',SW59.type,T2023.moor,T2023.dep);
  title(S,'interpreter','none');


  figure(4); clf
  plot(T2304.mday,T2304.t); grid
  datetick; 
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2304  Temperature at %6.2fm Z',SW59.type,T2304.moor,T2304.dep);
  title(S,'interpreter','none');

  figure(5); clf
  plot(T2300.mday,T2300.t); grid
  datetick;
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2300  Temperature at %6.2fm Z',SW59.type,T2300.moor,T2300.dep);
  title(S,'interpreter','none');

  figure(6); clf
  plot(T2297.mday,T2297.t); grid
  datetick;
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2297  Temperature at %6.2fm Z',SW59.type,T2297.moor,T2297.dep);
  title(S,'interpreter','none');

  figure(7); clf
  plot(T2298.mday,T2298.t); grid
  datetick;
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2298  Temperature at %6.2fm Z',SW59.type,T2298.moor,T2298.dep);
  title(S,'interpreter','none');

  figure(8); clf
  plot(T2049.mday,T2049.t); grid
  datetick;
  set(gca,'ylim',[5 27]);
  ylabel('temp (C)');
  S = sprintf('%s %s_T2049  Temperature at %6.2fm Z',SW59.type,T2049.moor,T2049.dep);
  title(S,'interpreter','none');

  drawnow
end








