% --------------------------------------------------------
%    plot_SW34
%
%
% SW34                  124     27 jul 14:21    Env. Mooring
%                                       38 56.37  72 52.566
%       Mini-T  2071    1                       SW34-T2071.dat
%       SBE37   396     12        -ends 28 Aug  SW34-SBE37-0396.cap
%       SBE39   18      21        -ends 10 Sept SW34-SBE39-0018.cap
%       SBE37   716     31        -ends 4 Sept  SW34-SBE37-0716.cap
%       SBE39   19      42        -ends 10 Sept SW34-SBE39-0019.cap
%       SBE37   458     53        -ends 4 Sept  SW34-SBE37-0458.cap
%       SBE39   20      64        -ends 10 Sept SW34-SBE39-0020.cap
%       SBE37   1132    75        -ends 3 Sept  SW34-SBE37-1132.cap
%       SBE39   21      86        -ends 10 Sept SW34-SBE39-0021.cap
%       SBE37   715     97        -ends 4 Sept  SW34-SBE37-0715.cap
%       SBE39   24      106                     SW34-SBD39-0024.dmp
%       SBE37   403     118       -ends 28 Aug  SW34-SBD37-0403.cap
%       Mini-T  2072    121.5                   SW34-T2072.DAT
%
%   SBE37 0396, 0403  have temp, conductivity, and pressure
%   SBE37 0715, 0716, 0458, 1132 have temp and conductivity
%   SBE39's have temperature ONLY
%
%
% --------------------------------------------------------


load SW34.mat 


% for MSM continuous transmission only
sdate = datenum(2006,07,28,12,0,0);
edate = datenum(2006,07,31,0,0,0);

% For entire deployment
% sdate = datenum(2006,07,27,12,0,0);
% edate = datenum(2006,09,12,12,0,0);
   
   
  % interpolate to same grid for combining...

  Tinc = (edate-sdate)/(24*60);
  Tnew = sdate:Tinc:edate;


  t2071.t = linterp(T2071.mday,T2071.t,Tnew);
  s0018.t = linterp(S0018.mday,S0018.t,Tnew);
  s0019.t = linterp(S0019.mday,S0019.t,Tnew);
  s0020.t = linterp(S0020.mday,S0020.t,Tnew);
  s0021.t = linterp(S0021.mday,S0021.t,Tnew);
  t2072.t = linterp(T2072.mday,T2072.t,Tnew);

  temp = [t2071.t; s0018.t; s0019.t ; s0020.t; s0021.t; t2072.t ];
  Z = SW34.Zsens([ 1 3 5 7 9 13]);
  

  figure(7);clf

  pcolor(Tnew,Z,temp); shading('interp'); axis('ij'); datetick
  set(gca,'xlim',[Tnew(1) Tnew(end)]);
  
  set(7,'renderer','zbuffer');

  hcb = colorbar;
  o_pos = get(gca,'position');
  set(hcb,'position',[.83 .11 .03 .4]);
  set(gca,'position',o_pos);

  set(get(hcb,'title'), 'string','Temp ^oC');
  ylabel('Depth (m)');  xlabel('Date 2006 (GMT)');
  title('Temperature  at SW34');
 
  
% average saliniyt was 34 ppt for 9/08, so will use to calculate SSP



  t2071.c = soundspeed(34,t2071.t,Z(1));
  s0018.c = soundspeed(34,s0018.t,Z(2));
  s0019.c = soundspeed(34,s0019.t,Z(3));
  s0020.c = soundspeed(34,s0020.t,Z(4));
  s0021.c = soundspeed(34,s0021.t,Z(5));
  t2072.c = soundspeed(34,t2072.t,Z(6));

  C = [t2071.c; s0018.c; s0019.c ; s0020.c; s0021.c; t2072.c ];
  Z = SW34.Zsens([ 1 3 5 7 9 13]);
  


  figure(8);clf

  set(8,'renderer','zbuffer');
  pcolor(Tnew,Z,C); shading('interp'); axis('ij'); datetick
  set(gca,'xlim',[Tnew(1) Tnew(end)]);
  

  hcb = colorbar;
  o_pos = get(gca,'position');
  set(hcb,'position',[.83 .11 .03 .4]);
  set(gca,'position',o_pos);

  set(get(hcb,'title'), 'string','C (m/s)');
  ylabel('Depth (m)');  xlabel('Date 2006 (GMT)');
  title('Soundspeed  at SW34');
  

T = Tnew;

% save sw34_soundspeed  C temp Z T 

% -----------------------------------------------------------
