% -----------------------------------------------------------
%      plot_SW45
%
%    loads data and makes a color plot of temp at SW45
%
% SW45                  82.5    28 jul 15:26    NRL 300Hz source
%                                       39 10.9574  72 56.575
%       Mini-T  2078    1       lost
%       SBE-39  3130    15       SW45-SBE39-3130.cap
%       Mini-T  2079    20       SW45-T2079.dat
%       Mini-T  2080    25       SW45-T2080.dat
%       Mini-T  2081    30       SW45-T2081.dat
%       Mini-T  2083    35       SW45-T2083.dat
%       Mini-T  2084    40       SW45-T2084.dat
%       Mini-T  2085    45       SW45-T2085.dat
%       Mini-T  2091    50       SW45-T2091.dat
%       Mini-T  2092    60       SW45-T2092.dat
%       Mini-T  2093    68       SW45-T2093.dat
%       Mini-T  2100    72       SW45-T2100.dat
%
%
%
% ---------------------------------------------------------


load SW45;

mst = datenum(2006,7,29);
mend = datenum(2006,9,5);

mt = mst:1/60/24:mend;

Z = SW45.Zsens;

S1 = interp1(S3130.mday,S3130.t,mt);
T2 = interp1(T2079.mday,T2079.t,mt);
T3 = interp1(T2080.mday,T2080.t,mt);
T4 = interp1(T2081.mday,T2081.t,mt);
T5 = interp1(T2083.mday,T2083.t,mt);
T6 = interp1(T2084.mday,T2084.t,mt);
T7 = interp1(T2085.mday,T2085.t,mt);
T8 = interp1(T2091.mday,T2091.t,mt);
T9 = interp1(T2092.mday,T2092.t,mt);
T10 = interp1(T2093.mday,T2093.t,mt);
T11 = interp1(T2100.mday,T2100.t,mt);

T = [S1; T2; T3; T4; T5; T6; T7; T8; T9; T10; T11];

Ta = [T2; T3; T4; T5; T6; T7; T8; T9; T10; T11];
Za = Z([2:11]);

pcolor(mt,Z,T);shading('interp');
axis('ij');  datetick

title('SW47 Temperature','fontweight','b');
xlabel('Date','fontweight','b'); ylabel('Depth (m)','fontweight','b');

caxis([8 30]);
hcb = colorbar('v6');
set(hcb,'position',[0.83 0.15 0.029 0.4075]);
set(get(hcb,'title'),'string','Deg(c)');

box('on');set(gca,'linewidth',2);set(gca,'ticklength',[0 0])



