% -----------------------------------------------------------
%      plot_SW47
%
%    loads data and makes a color plot of temp at SW47
%
%   load_sw47 must be in the path
%
% SW47			58	30 jul 20:56	WHOI 224Hz source	
%					39 09.199  73 21.490
%	Mini-T	279     1	 SW47-T0279.dat
%	SBE39	321     14	 SW47-SBE39-0321.cap
%	Mini-T	2086	20	 SW47-T2086.dat
%	Mini-T	276     25	 SW47-T0276.dat
%	Mini-T	2088	30	 SW47-T2088.dat
%	Mini-T	278     35      0 	Flooded, no data  <---	
%	Mini-T	2090	40	 SW47-T2090.dat
%	Mini-T	2037	55.5 SW47-T2037.dat
%
% ---------------------------------------------------------


load_sw47

tst  = 222.0;
tend = 248.0;

mst = datenum(2006,7,31);
mend = datenum(2006,9,5);

mt = mst:1/60/24:mend;

Z = SW47.Zsens;

T1 = interp1(T0279.mday,T0279.t,mt);
S1 = interp1(S0321.mday,S0321.t,mt);
T2 = interp1(T2086.mday,T2086.t,mt);
T3 = interp1(T0276.mday,T0276.t,mt);
T4 = interp1(T2088.mday,T2088.t,mt);
T5 = interp1(T2090.mday,T2090.t,mt);
T6 = interp1(T2037.mday,T2037.t,mt);

T = [T1; S1; T2; T3; T4; T5; T6];

Ta = [T1; T2; T3; T4; T5; T6];
Za = Z([1 3:7]);

pcolor(mt,Z,T);shading('interp');
axis('ij');  datetick

title('SW47 Temperature','fontweight','b');
xlabel('Date','fontweight','b'); ylabel('Depth (m)','fontweight','b');

caxis([8 30]);
hcb = colorbar('v6');
set(hcb,'position',[0.83 0.15 0.029 0.4075]);
set(get(hcb,'title'),'string','Deg(c)');

box('on');set(gca,'linewidth',2);set(gca,'ticklength',[0 0])



