function  SBE = read_sbe(filename,CODE,MOORING,DEPTH);
% -----------------------------------------------
%      FILENAME:   SBE file to read
%      CODE:       't','tp','tcp', 'tc'
%                    temp, pressure-temp, temp-pressure-conductivity, temp-conductivity
%      MOORING:    mooring name (usually SW and a number, ie SW14)
%      DEPTH:      Depth (m) of sensor
%
%   loads data from SBE
%
%   assumes SBE data has been converted to something matlab
%    friendly.   Perhaps will modify for raw data files later.
%
%  returns: 
% SBE.t   	temperature 
% SBE.yr   	year
% SBE.mon  	month
% SBE.day  	day
% SBE.hr   	hour
% SBE.min  	minute
% SBE.sec  	second
% SBE.mday     date in matlab format
%
%
%
% ----------------------------------------------


if (nargin < 2),
   error('Needs arguments to load_sbe program\n');
elseif (nargin == 2),
   moor = NaN;
   depth = NaN;
elseif (nargin == 3),
   moor = MOORING;
   depth = NaN; 
elseif (nargin == 4), 
   moor = MOORING;
   depth = DEPTH; 
else
  error('Too many arguments to loading program\n');
end 

% ------------------------------------------------------
% read in file according to format

Dat = load(filename);

switch CODE

   case 't',			%  temp recorded only
  
	SBE.t    = Dat(:,1);
	SBE.dep  = depth;
	SBE.yr   = Dat(:,4);
	SBE.mon  = Dat(:,3);
	SBE.day  = Dat(:,2);
	SBE.hr   = Dat(:,5);
	SBE.min  = Dat(:,6);
	SBE.sec  = Dat(:,7);
	SBE.moor = moor;
	SBE.mday = datenum(SBE.yr,SBE.mon,SBE.day,SBE.hr,SBE.min,SBE.sec );
         
  case 'tp',			%  temp and pressure recorded only 

	SBE.t    = Dat(:,1);
	SBE.p    = Dat(:,2);
	SBE.dep  = depth;
	SBE.yr   = Dat(:,5);
	SBE.mon  = Dat(:,4);
	SBE.day  = Dat(:,3);
	SBE.hr   = Dat(:,6);
	SBE.min  = Dat(:,7);
	SBE.sec  = Dat(:,8);
	SBE.moor = moor;
	SBE.mday = datenum(SBE.yr,SBE.mon,SBE.day,SBE.hr,SBE.min,SBE.sec );

  case {'tcp','tpc'}

 	SBE.t    = Dat(:,1);
	SBE.p    = Dat(:,3);
	SBE.con  = Dat(:,2);
	SBE.dep  = depth;
	SBE.yr   = Dat(:,6);
	SBE.mon  = Dat(:,5);
	SBE.day  = Dat(:,4);
	SBE.hr   = Dat(:,7);
	SBE.min  = Dat(:,8);
	SBE.sec  = Dat(:,9);
	SBE.moor = moor;
	SBE.mday = datenum(SBE.yr,SBE.mon,SBE.day,SBE.hr,SBE.min,SBE.sec );

   case 'tc',

 	SBE.t    = Dat(:,1);
	SBE.con  = Dat(:,2);
	SBE.dep  = depth;
	SBE.yr   = Dat(:,5);
	SBE.mon  = Dat(:,4);
	SBE.day  = Dat(:,3);
	SBE.hr   = Dat(:,6);
	SBE.min  = Dat(:,7);
	SBE.sec  = Dat(:,8);
	SBE.moor = moor;
	SBE.mday = datenum(SBE.yr,SBE.mon,SBE.day,SBE.hr,SBE.min,SBE.sec );
       
   otherwise

        error('Code sepcification problem in read_sbe\n');

   end

% ----------------------------------------------------------




        
