function  TID = read_TID(filename,MOORING,DEPTH);
% -----------------------------------------------
%      FILENAME:   TID file to read
%      MOORING:    mooring name (usually SW and a number, ie SW14)
%      DEPTH:      Depth (m) of sensor
%
%   loads data from TID file
%
%   assumes TID data has been converted to something matlab
%    friendly.   Perhaps will modify for raw data files later.
%
%  returns: 
% TID.t   	temperature
% TID.p   	pressure 
% TID.yr   	year
% TID.mon  	month
% TID.day  	day
% TID.hr   	hour
% TID.min  	minute
% TID.sec  	second
% TID.mday     date in matlab format
%
%
%
% ----------------------------------------------

if(nargin < 1),
   error('Needs arguments to loading program\n');
elseif(nargin == 1),
   moor = NaN;
   depth = NaN;
elseif(nargin == 2),
   moor = MOORING;
   depth = NaN;
elseif(nargin == 3),
   moor = MOORING;
   depth = DEPTH;
else
  error('Too many arguments to loading program\n');
end




% ------------------------------------------------------
% read in file according to format

Dat = load(filename);
 
   
	TID.p   = Dat(:,8);
	TID.t   = Dat(:,9);
	TID.dep = depth;
	TID.yr  = Dat(:,4);
	TID.mon = Dat(:,2);
	TID.day = Dat(:,3);
	TID.hr  = Dat(:,5);
	TID.min = Dat(:,6);
	TID.sec = Dat(:,7);
	TID.moor = moor;
	TID.mday  = datenum(TID.yr,TID.mon,TID.day,TID.hr,TID.min,TID.sec );
 

% ----------------------------------------------------------




        
