function Tpod = read_tpod(filename,MOORING,DEPTH)
% ------------------------------------------------------------------
%    load_tpod(FILENAME,MOORING,DEPTH);
%
%      FILENAME:   Tpod file to read
%      MOORING:    mooring name (usually SW and a number, ie SW14)
%      DEPTH:      Depth (m) of sensor
%
%   loads data from seamon tpod 
%
%   assumes tpod data has been converted to something matlab
%    friendly.   Perhaps will modify for raw data files later.
%
%  returns: 
% Tpod.t   	temperature 
% Tpod.yr   	year
% Tpod.mon  	month
% Tpod.day  	day
% Tpod.hr   	hour
% Tpod.min  	minute
% Tpod.sec  	second
% Tpod.mday     date in matlab format


% -------------------------------------------------------------------

if(nargin < 1),
   error('Needs arguments to loading program\n');
elseif(nargin == 1),
   moor = NaN;
   depth = NaN;
elseif(nargin == 2),
   moor = MOORING;
   depth = NaN; 
elseif(nargin == 3), 
   moor = MOORING;
   depth = DEPTH; 
else
  error('Too many arguments to loading program\n');
end 


Dat = load(filename);


Tpod.t   = Dat(:,8);
Tpod.yr  = Dat(:,4) + 2000;
Tpod.mon = Dat(:,3);
Tpod.day = Dat(:,2);
Tpod.hr  = Dat(:,5);
Tpod.min = Dat(:,6);
Tpod.sec = Dat(:,7);
Tpod.mday  = datenum(Tpod.yr, Tpod.mon, Tpod.day, ...
                           Tpod.hr, Tpod.min, Tpod.sec );

Tpod.dep = depth;
Tpod.moor = moor;

% -----------------------------------------------------------------------------

