
function [psifinal,x,y,z,M,psi1]=shelf3dpeV5(nz,numstep,fr,c0,envfile,wid,steplength,aspect,dep,zs,sidestep)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Parabolic equation simulation of 3-D (x,y,z) acoustic propagation.
% An initial condition psi(x_0,y,z) is marched forward using the split-step
% method to a final range psi (range, y, z). 
%
% tim d  vertical version march 2006,  image source removed etc
%  new version pe3td completely different from pe3de
%
% rev 3 uses triple-wide environment to allow good wave spacing.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% persistent rhosq screen Y Z atten fr
lambda=c0/fr ;
% -----------set up grid ....................................................
dx=steplength;

ny=nz;
dy=wid/(nz-0.5);
dz=dy/aspect;

ntransz=nz; ntransy=ny;
nstep=numstep;
%z     =  dz/2+(0:(nz-1))*dz;
%zt     =  [-z(nz:-1:1) z];
y     =  (-0.5*ny*dy):dy:(0.5*ny*dy)-dy;
z=y/aspect;

[Y,Z]=meshgrid(y,z);
zso1=min(find(z > zs));
zso2=max(find(z < -zs));       % source and image source pair
rhosq=(Y.^2 +Z.^2);
d1=(Y.^2 + (Z-Z(zso1,1)).^2);
d2=(Y.^2 + (Z-Z(zso2,1)).^2);    %  symmetric about zero

Ly=max(y)-min(y);
Lz=max(z)-min(z);

%************************************************************************
%                       Point Source                                
% *************************************************************************
k0        = 2.0*pi/lambda; % 2000 is about 26 times 75 Hz
%fac       = 12;  this gives ko/fac= .025 at 75 Hz (Colosi version)
   %  fac smaller makes a tighter source
fac=k0/.4 ; %  k0/fac is like ka ...  use .6 for 4000 Hz,  .025 for 100
disp([ 'size scale of source (Ko/fac)sq : ' num2str((k0/fac)^2)])
%psi= sqrt(k0/fac) * exp( -(k0/fac)^2 *rhosq ); %  axisymmetric source at postion zero (0,0)
psi= sqrt(k0/fac) * exp( -(k0/fac)^2 *d1 );
psi=psi - (sqrt(k0/fac) * exp( -(k0/fac)^2 *d2 ));
clear d1 d2 rhosq
clear psiz psiy ido dum

% ----------------------   wavenumber some domain set up  ------------------
ky=(2*pi/(Ly))*[0:ny/2];
ky(ntransy:-1:ny/2+1)=-ky(2:ny/2+1);
ky=ones(ntransz,1)*ky;
kz= aspect*ky';       % make symmetric


% ----- run environment design code -- produces attbo, cin  -- requires Y and Z
eval(envfile);

% ------------------        Attenuation function (Sponge layers all around)
hh=max(abs(z));
alpha=lambda/50 ; beta=4*4/dx;  % alpha 4/h  for 4 kHz    % was lamb/2 for 10k hz
att= exp( -beta*dx*exp( -((z(nz:-1:1)-hh)/(alpha*hh)).^2));
attenz=att.*fliplr(att);
attenz=attenz'*ones(1,ny);

hh=max(abs(y));
alpha=lambda/50 ; beta=4*4/dx;  % alpha 4/h  for 4 kHz    % was lamb/2 for 10k hz
att= exp( -beta*dx*exp( -((y(nz:-1:1)-hh)/(alpha*hh)).^2));
atteny=att.*fliplr(att);
atteny=atteny'*ones(1,nz);
atteny=atteny';
atten=attenz.*atteny;
clear atteny attenz

atten=atten.*attbo;

% ---------------------         Phase screen P ........
U=(cin-c0)/c0;                        % in tw, cin is too wide.....
screen=exp(-i*k0*dx*U);
clear U cin

% ---------------  propagate here, in the loop below

%     standard PE     fr=exp(-i*0.5*dx*(kz.^2+ky.^2)/k0); 
%     WAPE Thomson Chapman 1983 JASA
kappasq = (kz.^2+ky.^2);
fr=exp(-i*0.5*dx*kappasq./ (  (k0^2 -kappasq).^(0.5) + k0 ) ); 
disp('____________ WAPE _________________')
clear kappasq

dista=0;
psi1=psi;
[j1,j2]=size(screen);
midl=find( abs(yin) < 1e-8);
rng=(midl-(nz/2) ):(midl+ (nz/2)-1);

cou=0;figure(1);clf ; coun=0;
offse=sidestep;
for jj=1:nstep
    screenm=screen(:,rng+offse);    % vw mode use middle....
    offse=offse-sidestep;
    psi=atten.*psi.*screenm;
    
    if(jj==1 | mod(jj,6)==0) 
       wat= find(  z > -(dep+5) & z < .5);
       subplot(211)
       pcolor(y(1:2:end),z(wat), abs(psi(wat,1:2:end)));shading flat;
     %caxis([ .4 1.2]);
       caxis([ max(max(abs(psi)))*.1 max(max(abs(psi))) ])
       colorbar('southoutside')
       subplot(212)
       pcolor(y(1:2:end),z(wat),angle(screenm(wat,1:2:end)));shading flat
       caxis( [-.4 .4 ])
        cou=cou+1;
         % axis equal
        title(num2str(dista));
        pause(.2)
        
       % M(cou)=getframe(gcf);
    end
    
    psi=fft2(psi);
    %psi(1,1)=0;   % started as 1,:
    psi=psi.*fr;
    psi=ifft2(psi);
    dista  = dista + dx;
    disp(['to : ' num2str(dista) ' shift: ' num2str(sidestep) ' position: ' num2str(offse)])
    
        if(0)  % plot and movie stuff 
        pcolor( angle(psi((512-100):(512+100),(512-100):(512+100))));shading flat;colorbar
        coun=coun+1;
        axis equal
        title(num2str(dista));
        M(coun)=getframe(gcf);
        end 
        
        if(0) % if(mod(distance,dx*4)==0)
            plot(angle(psi(:,nz/2)-angle(psi1(:,nz/2))))
        end
    end

x=dista;
psifinal=psi;
M='off';
